/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DL3Y.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DL3Y *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DL3Y_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DL3Y();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DL3Y::Heavy_WSTD_DL3Y(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_HfB8f7Kh);
  numBytes += sLine_init(&sLine_alTVnMXF);
  numBytes += sLine_init(&sLine_KwGtZbyF);
  numBytes += sLine_init(&sLine_Pd4be4B6);
  numBytes += sLine_init(&sLine_KkIkFAF3);
  numBytes += sBiquad_init(&sBiquad_s_YMA7I0lb);
  numBytes += sLine_init(&sLine_qoUDselp);
  numBytes += sLine_init(&sLine_vL3RoZiy);
  numBytes += sLine_init(&sLine_scCwlgNL);
  numBytes += sLine_init(&sLine_4heJ8ozW);
  numBytes += sBiquad_init(&sBiquad_s_B6fh4qWa);
  numBytes += sLine_init(&sLine_gjgZU9yb);
  numBytes += sLine_init(&sLine_p3SPLn1E);
  numBytes += sLine_init(&sLine_qzWRJBPU);
  numBytes += sLine_init(&sLine_Uxy0D7ls);
  numBytes += sLine_init(&sLine_et3qMfIx);
  numBytes += sBiquad_init(&sBiquad_s_KXwt20U1);
  numBytes += sLine_init(&sLine_buIO0R4L);
  numBytes += sLine_init(&sLine_BmUcqCOC);
  numBytes += sLine_init(&sLine_PBY1jd7q);
  numBytes += sLine_init(&sLine_vuzcBGAp);
  numBytes += sLine_init(&sLine_UwBlNfmI);
  numBytes += sBiquad_init(&sBiquad_s_bNOdBFrR);
  numBytes += sLine_init(&sLine_eo17yxQ0);
  numBytes += sLine_init(&sLine_jnZrF0HV);
  numBytes += sLine_init(&sLine_urFMGpSK);
  numBytes += sLine_init(&sLine_cayeb2i8);
  numBytes += sBiquad_init(&sBiquad_s_xlScPdSJ);
  numBytes += sLine_init(&sLine_WGibibhE);
  numBytes += sLine_init(&sLine_G6gOMWzu);
  numBytes += sLine_init(&sLine_zQ2Y2qt8);
  numBytes += sLine_init(&sLine_vPZYf5m3);
  numBytes += sLine_init(&sLine_XTkMygb3);
  numBytes += sBiquad_init(&sBiquad_s_2ysZNWU5);
  numBytes += sLine_init(&sLine_mAsrNk8o);
  numBytes += sTabread_init(&sTabread_F22A441M, &hTable_CWKOQWeU, true);
  numBytes += sLine_init(&sLine_Z3jkDBZ1);
  numBytes += sLine_init(&sLine_IxAyg3cQ);
  numBytes += sTabread_init(&sTabread_qvGLJlfv, &hTable_PGchTqhI, true);
  numBytes += sLine_init(&sLine_pKiTGsMO);
  numBytes += sRPole_init(&sRPole_Q2Yhb3Xw);
  numBytes += sDel1_init(&sDel1_BsKastg3);
  numBytes += sTabwrite_init(&sTabwrite_FZBcJac7, &hTable_CWKOQWeU);
  numBytes += sRPole_init(&sRPole_2715Jlpd);
  numBytes += sDel1_init(&sDel1_9RR17UoQ);
  numBytes += sTabwrite_init(&sTabwrite_a5QJ4eun, &hTable_PGchTqhI);
  numBytes += sLine_init(&sLine_9J54lYWS);
  numBytes += sLine_init(&sLine_egE49uz6);
  numBytes += sRPole_init(&sRPole_mjbbPxgw);
  numBytes += sEnv_init(&sEnv_pPlNAAca, 1024, 512);
  numBytes += sRPole_init(&sRPole_0eLfua49);
  numBytes += sLine_init(&sLine_1kP4rgcD);
  numBytes += sLine_init(&sLine_IEHxJXbg);
  numBytes += sRPole_init(&sRPole_qBYtgXPV);
  numBytes += sEnv_init(&sEnv_yvXQmYyh, 1024, 512);
  numBytes += sRPole_init(&sRPole_tnQ8pSDX);
  numBytes += sLine_init(&sLine_wEoA3xCZ);
  numBytes += sTabread_init(&sTabread_AyNIbarD, &hTable_0TAHHwZp, true);
  numBytes += sLine_init(&sLine_EVon1jSf);
  numBytes += sLine_init(&sLine_OMQsBF0A);
  numBytes += sTabread_init(&sTabread_hauLLylu, &hTable_2slfKaAf, true);
  numBytes += sLine_init(&sLine_tCIdo3OO);
  numBytes += sRPole_init(&sRPole_6i7Ye4m4);
  numBytes += sDel1_init(&sDel1_DdetReD7);
  numBytes += sTabwrite_init(&sTabwrite_k6EX2Ec1, &hTable_0TAHHwZp);
  numBytes += sRPole_init(&sRPole_T0WnH4Df);
  numBytes += sDel1_init(&sDel1_MyrUwGdw);
  numBytes += sTabwrite_init(&sTabwrite_7AZkZ8k8, &hTable_2slfKaAf);
  numBytes += sLine_init(&sLine_1eD5HXG7);
  numBytes += sLine_init(&sLine_nAl6Eubo);
  numBytes += sRPole_init(&sRPole_zRzRVyHy);
  numBytes += sEnv_init(&sEnv_npDA7nk6, 1024, 512);
  numBytes += sRPole_init(&sRPole_CpuLz2kO);
  numBytes += sLine_init(&sLine_LGOOWNep);
  numBytes += sLine_init(&sLine_vX2wY3s1);
  numBytes += sRPole_init(&sRPole_qPLKnl10);
  numBytes += sEnv_init(&sEnv_AFkwDwwx, 1024, 512);
  numBytes += sRPole_init(&sRPole_XAtU9b5P);
  numBytes += sLine_init(&sLine_PdXXWjW3);
  numBytes += sTabread_init(&sTabread_OhtVlxcf, &hTable_tsPDcfOd, true);
  numBytes += sLine_init(&sLine_QpnaNcY1);
  numBytes += sLine_init(&sLine_WGF5eXzV);
  numBytes += sTabread_init(&sTabread_X2EEAVfE, &hTable_6gHb7SX0, true);
  numBytes += sLine_init(&sLine_Sz1FCUmg);
  numBytes += sRPole_init(&sRPole_uMXh1QAP);
  numBytes += sDel1_init(&sDel1_lNmLPvoo);
  numBytes += sTabwrite_init(&sTabwrite_gGztJXJA, &hTable_tsPDcfOd);
  numBytes += sRPole_init(&sRPole_MxBeHuT9);
  numBytes += sDel1_init(&sDel1_PgIayqgi);
  numBytes += sTabwrite_init(&sTabwrite_YiOIMMZD, &hTable_6gHb7SX0);
  numBytes += sLine_init(&sLine_RiiDhfRN);
  numBytes += sLine_init(&sLine_W0LaHzsa);
  numBytes += sRPole_init(&sRPole_Y8CtWcFE);
  numBytes += sEnv_init(&sEnv_OYV90pPc, 1024, 512);
  numBytes += sRPole_init(&sRPole_ob2RWZXn);
  numBytes += sLine_init(&sLine_8J98VVQg);
  numBytes += sLine_init(&sLine_B8XC1E0x);
  numBytes += sRPole_init(&sRPole_zrv8PUwB);
  numBytes += sEnv_init(&sEnv_teB4zooV, 1024, 512);
  numBytes += sRPole_init(&sRPole_IqtMGWcU);
  numBytes += cVar_init_f(&cVar_dR1uxmMW, 0.0f);
  numBytes += cVar_init_f(&cVar_HOgPLNOB, 0.0f);
  numBytes += cVar_init_f(&cVar_2V4smvIF, 0.0f);
  numBytes += cVar_init_f(&cVar_P0SMmeIA, 0.0f);
  numBytes += cSlice_init(&cSlice_UCws8fEV, 1, -1);
  numBytes += cVar_init_f(&cVar_zSd7KgEg, 1337.0f);
  numBytes += cVar_init_f(&cVar_Vs7HjouW, 0.0f);
  numBytes += cIf_init(&cIf_vyNHhfgZ, false);
  numBytes += cIf_init(&cIf_jWbnv0e1, false);
  numBytes += cBinop_init(&cBinop_gRmUmBKo, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Gr4DBHhe, false);
  numBytes += cBinop_init(&cBinop_xoELwePg, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_1FOJt5be, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_am2HfGFf, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_w89zrCSU, 0.0f);
  numBytes += cIf_init(&cIf_PUlMyPbA, false);
  numBytes += cIf_init(&cIf_2olS1ZDh, false);
  numBytes += cBinop_init(&cBinop_Exlsvjdq, 0.0f); // __pow
  numBytes += cIf_init(&cIf_OwQwzorW, false);
  numBytes += cBinop_init(&cBinop_WhGWBTpQ, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_JqtChIz4, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_4jwm0jEF, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_4BBwMvBi, 0.0f);
  numBytes += cIf_init(&cIf_kzQOkk2i, false);
  numBytes += cIf_init(&cIf_zlsvrnkc, false);
  numBytes += cBinop_init(&cBinop_l9ef4jlG, 0.0f); // __pow
  numBytes += cIf_init(&cIf_d8AXZUz4, false);
  numBytes += cBinop_init(&cBinop_ZIBk7Lab, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_hNdhmpJ9, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_lOn9sP5b, -15.0f); // __eq
  numBytes += cIf_init(&cIf_m7pJWo7d, false);
  numBytes += cSlice_init(&cSlice_CP3C2UKq, 1, -1);
  numBytes += cVar_init_f(&cVar_SN8ntG52, 0.0f);
  numBytes += cSlice_init(&cSlice_GNpd6yoz, 1, -1);
  numBytes += cVar_init_f(&cVar_JvN7CrtE, 0.0f);
  numBytes += cSlice_init(&cSlice_8pSBsGNA, 1, -1);
  numBytes += cVar_init_f(&cVar_fadgWOAN, 0.0f);
  numBytes += cSlice_init(&cSlice_RG8fjak9, 1, -1);
  numBytes += cVar_init_f(&cVar_LByYkg0G, 0.313f);
  numBytes += cBinop_init(&cBinop_bjIXS2LI, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_wR8w5VXe, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_KHnbpNMG, 0.0f);
  numBytes += cVar_init_f(&cVar_sHJen0hU, 1337.0f);
  numBytes += cVar_init_f(&cVar_p5zUw7jy, 0.3f);
  numBytes += cBinop_init(&cBinop_I14B8NfX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1TZEEhQX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2Gbgi0Cd, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Ay9M6sZF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_kD5eQe2d, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_CeoouEmv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LJQfpvo6, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_tI0lFLl0, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_TddxtTT8, 0.0f);
  numBytes += cVar_init_f(&cVar_gEoBKNm3, 1337.0f);
  numBytes += cVar_init_f(&cVar_eENrEEUk, 0.313f);
  numBytes += cBinop_init(&cBinop_k7cM7Nw0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_hQeeyKUi, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dZoRv71W, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_wMIhcTjO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_kg9n92fm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Tv2NyBcI, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_7C1tlPPz, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_7pMYfOEV, 0.0f);
  numBytes += cVar_init_f(&cVar_RvuVwxs4, 1037.0f);
  numBytes += cVar_init_f(&cVar_y8tzcqoY, 0.4f);
  numBytes += cBinop_init(&cBinop_J5Ja3V6Q, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_p3u0AOc3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QffQ4kiZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_oCNnkQPS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qQg8CeHn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_0GrpSxPt, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_KZAOeiZd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rtYFa6uk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4KBeqg7p, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_et00kSuF, 1, -1);
  numBytes += cVar_init_f(&cVar_wvrbnpa8, 1337.0f);
  numBytes += cVar_init_f(&cVar_upfMbw8d, 0.0f);
  numBytes += cIf_init(&cIf_uwQFxvhz, false);
  numBytes += cIf_init(&cIf_Rxr6Q266, false);
  numBytes += cBinop_init(&cBinop_5L1rMkUE, 0.0f); // __pow
  numBytes += cIf_init(&cIf_hgoPQv1I, false);
  numBytes += cBinop_init(&cBinop_MpfPjbo8, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_FqSHitcH, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_744J8DWQ, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_Ag0p5hQn, 0.0f);
  numBytes += cIf_init(&cIf_Az0dmANw, false);
  numBytes += cIf_init(&cIf_n4S8RFMw, false);
  numBytes += cBinop_init(&cBinop_1PNNKUPs, 0.0f); // __pow
  numBytes += cIf_init(&cIf_REjXHOI1, false);
  numBytes += cBinop_init(&cBinop_JLWal8ZI, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Y7wv6WUA, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_H79sxgMl, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_E5yKBeIZ, 0.0f);
  numBytes += cIf_init(&cIf_b7F2Z8fE, false);
  numBytes += cIf_init(&cIf_chOM2NfK, false);
  numBytes += cBinop_init(&cBinop_rfYtltWa, 0.0f); // __pow
  numBytes += cIf_init(&cIf_PF5JeXh9, false);
  numBytes += cBinop_init(&cBinop_8uTeeizN, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_CaISUOkl, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_yW7krlPp, -15.0f); // __eq
  numBytes += cIf_init(&cIf_ncY9ugct, false);
  numBytes += cSlice_init(&cSlice_w4dx3eAl, 1, -1);
  numBytes += cVar_init_f(&cVar_s39Iwr0U, 0.0f);
  numBytes += cSlice_init(&cSlice_9gONzQrt, 1, -1);
  numBytes += cVar_init_f(&cVar_2RamqhcC, 0.0f);
  numBytes += cSlice_init(&cSlice_sLOd3ZWw, 1, -1);
  numBytes += cVar_init_f(&cVar_BmO7BZOM, 0.0f);
  numBytes += cSlice_init(&cSlice_ifE1xjM2, 1, -1);
  numBytes += cVar_init_f(&cVar_TV64yr9j, 0.313f);
  numBytes += cBinop_init(&cBinop_fDxbOX4K, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_DS554yI0, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_D1HbT1nf, 0.0f);
  numBytes += cVar_init_f(&cVar_qik2bFSf, 1337.0f);
  numBytes += cVar_init_f(&cVar_gCJbLTCZ, 0.3f);
  numBytes += cBinop_init(&cBinop_rT9T5ggx, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DPr61eEg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vomD4SLS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_TWi2RUE4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WdAI0PIu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_L4TI6tWB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_05Kpl9Je, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_eItUCOwA, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_UCEpO21g, 0.0f);
  numBytes += cVar_init_f(&cVar_cNnpjLqv, 1337.0f);
  numBytes += cVar_init_f(&cVar_mMpE4Hcl, 0.313f);
  numBytes += cBinop_init(&cBinop_rH3uiKi9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vpGVGSxu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_U26RlsTl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rRPHMexo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PiNHBtZR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_R9ZX6okM, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_EiwMSuUc, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_uXVxHb7v, 0.0f);
  numBytes += cVar_init_f(&cVar_PoIJfAbL, 1037.0f);
  numBytes += cVar_init_f(&cVar_Bk6hMwby, 0.4f);
  numBytes += cBinop_init(&cBinop_7VQ7E3hh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Jrm888Ni, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rnJ0gMFW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_A92DpLFs, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_P7Sl1rFY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ZC8lge5C, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_qVE7YLk9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YwcIDpxR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mqgeQyyS, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_O04QjTib, 5705.6f);
  numBytes += cVar_init_f(&cVar_S6IaTj51, 313.3f);
  numBytes += cBinop_init(&cBinop_KjK6GGBC, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_2lrXHtiG, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_Ygr3D9fz, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_pGbZ12Ub, 0.0f);
  numBytes += cVar_init_f(&cVar_FnTzIX64, 0.0f);
  numBytes += cVar_init_f(&cVar_2E47ak7X, 0.0f);
  numBytes += cVar_init_f(&cVar_aS3Gdal4, 0.0f);
  numBytes += cVar_init_f(&cVar_GhbHQAux, 0.0f);
  numBytes += cVar_init_f(&cVar_31jiv2pb, 0.0f);
  numBytes += cVar_init_f(&cVar_ewGwOSBS, 0.0f);
  numBytes += cVar_init_f(&cVar_kIU4E1gb, 0.0f);
  numBytes += cVar_init_f(&cVar_FUWa9NDu, 0.0f);
  numBytes += cVar_init_f(&cVar_9KO4oCea, 0.0f);
  numBytes += cVar_init_f(&cVar_XtqshasM, 0.0f);
  numBytes += cVar_init_f(&cVar_pxPuCY2V, 0.0f);
  numBytes += cSlice_init(&cSlice_rAh6N8hu, 1, -1);
  numBytes += cVar_init_f(&cVar_7dIGjUJA, 0.5f);
  numBytes += cSlice_init(&cSlice_QQTSyAvt, 1, -1);
  numBytes += cVar_init_f(&cVar_Oi0aItS1, 0.2f);
  numBytes += cSlice_init(&cSlice_10pkpCEA, 1, -1);
  numBytes += cVar_init_f(&cVar_tfZoSHmm, 500.0f);
  numBytes += sVarf_init(&sVarf_8GC5h7Mw, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_9be1RhPi, 600.0f);
  numBytes += cBinop_init(&cBinop_6ov4kNwK, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_BfTPhOAN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SUO9eorV, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_KVhsrcX9, 600.0f);
  numBytes += cBinop_init(&cBinop_MkkIsRzv, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_3jG7cdfA, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_vhgz510u, 4000.0f);
  numBytes += cBinop_init(&cBinop_wRVNK4hk, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_yYKnDHh0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4sTvt7Sf, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_50erY1lu, 4000.0f);
  numBytes += cBinop_init(&cBinop_SIoYPrv1, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_HCMyTsDp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MGowtGG9, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_ly2CpDa5, false);
  numBytes += cBinop_init(&cBinop_nR0FVgjn, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_OI6Ec8Ao, 20.0f);
  numBytes += cBinop_init(&cBinop_anfLNbIv, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_ybMNApE6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SeSclvrj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QlwrnJpB, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_JPXDaEub, false);
  numBytes += cBinop_init(&cBinop_la2P2sez, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_MsxTifPA, 20.0f);
  numBytes += cBinop_init(&cBinop_JIj5hQQJ, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_hEgBI23K, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_JqnFYYDH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_93erCWOz, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_PbOPyTPJ, 1, -1);
  numBytes += cVar_init_f(&cVar_C8dCOkNW, 0.25f);
  numBytes += cDelay_init(this, &cDelay_ohm7Vapg, 0.0f);
  numBytes += cDelay_init(this, &cDelay_ZFOJhjha, 0.0f);
  numBytes += hTable_init(&hTable_CWKOQWeU, 256);
  numBytes += cTabhead_init(&cTabhead_501pHXEM, &hTable_CWKOQWeU);
  numBytes += cVar_init_s(&cVar_FDcNsqkJ, "del-1349-delayL");
  numBytes += cDelay_init(this, &cDelay_PLKoGgG8, 0.0f);
  numBytes += cDelay_init(this, &cDelay_r4rwnNsE, 0.0f);
  numBytes += cBinop_init(&cBinop_QiKoG0dW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gCxVAou9, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_VD927jGG, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_0niCtFHR, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_4pPePPrr, 0.0f);
  numBytes += cDelay_init(this, &cDelay_1EkWKoRl, 0.0f);
  numBytes += hTable_init(&hTable_PGchTqhI, 256);
  numBytes += cTabhead_init(&cTabhead_qNTM3jpW, &hTable_PGchTqhI);
  numBytes += cVar_init_s(&cVar_1t0kq9gj, "del-1349-delayR");
  numBytes += cDelay_init(this, &cDelay_CDLF9W4D, 0.0f);
  numBytes += cDelay_init(this, &cDelay_ICfK9pAR, 0.0f);
  numBytes += cBinop_init(&cBinop_xEPyIa8F, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2HDkYwCr, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_v4voNlRW, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_mIttT3ys, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_6WDE2U7D, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_S3l9t3k4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Qyzx8RGU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eyK59vya, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_Ce6Jw9Hr, 1, -1);
  numBytes += cVar_init_f(&cVar_KcVLL99y, 0.5f);
  numBytes += cSlice_init(&cSlice_wM6sL3Yv, 1, -1);
  numBytes += cVar_init_f(&cVar_KOCYpNNc, 0.2f);
  numBytes += cSlice_init(&cSlice_qqGYDQR5, 1, -1);
  numBytes += cVar_init_f(&cVar_twrwoVBr, 500.0f);
  numBytes += sVarf_init(&sVarf_bk20T1U6, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_NGf4sACI, 600.0f);
  numBytes += cBinop_init(&cBinop_K4eo2Igf, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_U8n5Zwo5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5xDC1acT, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_JZUyP15e, 600.0f);
  numBytes += cBinop_init(&cBinop_S2vaXTTC, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_AsFhoWNn, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_7HoPe3eF, 4000.0f);
  numBytes += cBinop_init(&cBinop_CC6iPg5R, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_VrsB78nb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Yb5oFF0V, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_oSLhhQCu, 4000.0f);
  numBytes += cBinop_init(&cBinop_dxv0UED2, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_iLZtWhFM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SGCurf8n, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_LeBfrBep, false);
  numBytes += cBinop_init(&cBinop_FG7EGbe5, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_ntq0mLW8, 20.0f);
  numBytes += cBinop_init(&cBinop_E8HpofXe, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_aI3jOREu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uYPmLM6c, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AsLYJncj, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_Zw9qOZiR, false);
  numBytes += cBinop_init(&cBinop_YIUXnUgF, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_RJIwwFYB, 20.0f);
  numBytes += cBinop_init(&cBinop_ktNx9fMX, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_LDno1WxL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UFSFwlvR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_L0m9w3fL, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_3u0jjEYP, 1, -1);
  numBytes += cVar_init_f(&cVar_NLdwqvYZ, 0.25f);
  numBytes += cDelay_init(this, &cDelay_Ojz5TOIC, 0.0f);
  numBytes += cDelay_init(this, &cDelay_SFHfijQe, 0.0f);
  numBytes += hTable_init(&hTable_0TAHHwZp, 256);
  numBytes += cTabhead_init(&cTabhead_0X7J4I9b, &hTable_0TAHHwZp);
  numBytes += cVar_init_s(&cVar_MQ2AKT9H, "del-1428-delayL");
  numBytes += cDelay_init(this, &cDelay_mfO9sgcF, 0.0f);
  numBytes += cDelay_init(this, &cDelay_hmUkKOOs, 0.0f);
  numBytes += cBinop_init(&cBinop_GARuUu9p, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8kzgLYNM, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_RQaDRINF, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_GJeSToI8, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_qLQAzfpJ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_vYJtdHUL, 0.0f);
  numBytes += hTable_init(&hTable_2slfKaAf, 256);
  numBytes += cTabhead_init(&cTabhead_mT1FtaSr, &hTable_2slfKaAf);
  numBytes += cVar_init_s(&cVar_eClkqDOl, "del-1428-delayR");
  numBytes += cDelay_init(this, &cDelay_3msIjfdC, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Vws1PZGg, 0.0f);
  numBytes += cBinop_init(&cBinop_yYzzHPYh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3fANrXCg, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_dQQDwB2z, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_hIUElCy1, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_W7iTzzJm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_y9PLbjFQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OgS8SSWo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8waQ0F4l, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_JOLHuevH, 1, -1);
  numBytes += cVar_init_f(&cVar_tf6Mdqsa, 0.5f);
  numBytes += cSlice_init(&cSlice_PqYbBZhS, 1, -1);
  numBytes += cVar_init_f(&cVar_UpkDqmkD, 0.2f);
  numBytes += cSlice_init(&cSlice_CW6IzQKn, 1, -1);
  numBytes += cVar_init_f(&cVar_5PP4lbpI, 500.0f);
  numBytes += sVarf_init(&sVarf_cCFfodNy, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_JpEMlwb1, 600.0f);
  numBytes += cBinop_init(&cBinop_PPd7ayJa, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_RnPQOUXa, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OQUjnLcN, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_6KlGhQZQ, 600.0f);
  numBytes += cBinop_init(&cBinop_fDiaVjPt, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_G73wGL4l, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_FGIjolnh, 4000.0f);
  numBytes += cBinop_init(&cBinop_OUib0Mqx, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_I1VDkNm9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rDlQJ2It, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_JMqrIxpG, 4000.0f);
  numBytes += cBinop_init(&cBinop_tb1LDzaZ, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_ABBx7l3m, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_21BZj11C, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_B0kGWEIZ, false);
  numBytes += cBinop_init(&cBinop_9TOIeV5y, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_QPRAVli1, 20.0f);
  numBytes += cBinop_init(&cBinop_A1OyVFqj, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_EmUKfeuo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BApyv1Gq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4B923pwn, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_zUVbX7gt, false);
  numBytes += cBinop_init(&cBinop_FTGPWBEj, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_P5XMJ71r, 20.0f);
  numBytes += cBinop_init(&cBinop_1ZsiYOk6, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_DaCUl07F, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_yYc0wpvi, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RJWhLfGq, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_nAAhBA8j, 1, -1);
  numBytes += cVar_init_f(&cVar_OEqys86i, 0.25f);
  numBytes += cDelay_init(this, &cDelay_4RzxTjWH, 0.0f);
  numBytes += cDelay_init(this, &cDelay_oiRruCSi, 0.0f);
  numBytes += hTable_init(&hTable_tsPDcfOd, 256);
  numBytes += cTabhead_init(&cTabhead_ij6xZJJZ, &hTable_tsPDcfOd);
  numBytes += cVar_init_s(&cVar_HqC4WwzQ, "del-1507-delayL");
  numBytes += cDelay_init(this, &cDelay_Py5E7JBY, 0.0f);
  numBytes += cDelay_init(this, &cDelay_OTLpC7NJ, 0.0f);
  numBytes += cBinop_init(&cBinop_apxm0LdI, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dl1bHG6K, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_6ooDNKSQ, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_0C8VKAmM, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_LyZl5Kfs, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Kfpjj1sT, 0.0f);
  numBytes += hTable_init(&hTable_6gHb7SX0, 256);
  numBytes += cTabhead_init(&cTabhead_MMf7dAwu, &hTable_6gHb7SX0);
  numBytes += cVar_init_s(&cVar_oLo6Abwe, "del-1507-delayR");
  numBytes += cDelay_init(this, &cDelay_Cgw1edCG, 0.0f);
  numBytes += cDelay_init(this, &cDelay_FK0SRWxZ, 0.0f);
  numBytes += cBinop_init(&cBinop_SEki2U0h, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ZHXjWMfX, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_eY6XBFbk, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_kpzsJyUM, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_h9GEjUT0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5qgFHSVj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DRd2msG8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ldjf8K9x, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_nRZyyCus, 1.0f);
  numBytes += cIf_init(&cIf_GUT3AUAS, false);
  numBytes += cIf_init(&cIf_uCnfokaZ, false);
  numBytes += cVar_init_f(&cVar_9aJY6LP6, 0.0f);
  numBytes += cVar_init_f(&cVar_PYTtcpMD, 0.0f);
  numBytes += cVar_init_f(&cVar_d6DUnOim, 1.0f);
  numBytes += cIf_init(&cIf_s7UcZAU1, false);
  numBytes += cIf_init(&cIf_VZsmjUkK, false);
  numBytes += cVar_init_f(&cVar_OtGhFBXU, 0.0f);
  numBytes += cVar_init_f(&cVar_mlD6JQhQ, 0.0f);
  numBytes += cVar_init_f(&cVar_FkEyWuef, 1.0f);
  numBytes += cIf_init(&cIf_IahScxMj, false);
  numBytes += cIf_init(&cIf_Uqs9PG6N, false);
  numBytes += cVar_init_f(&cVar_1KaVOf5b, 0.0f);
  numBytes += cVar_init_f(&cVar_udjtFJzH, 0.0f);
  numBytes += cVar_init_f(&cVar_WKkeeLwL, 60000.0f);
  numBytes += cVar_init_f(&cVar_XaH6AMUS, 500.0f);
  numBytes += cSlice_init(&cSlice_X8AzfFFY, 1, -1);
  numBytes += cSlice_init(&cSlice_DAI0zMGu, 1, -1);
  numBytes += cVar_init_f(&cVar_9h2OcE6u, 0.0f);
  numBytes += cIf_init(&cIf_o18I9DCk, false);
  numBytes += cBinop_init(&cBinop_te16GYzz, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_BHAV7Ycj, 120.0f);
  numBytes += cBinop_init(&cBinop_ncPVQZb8, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_8xyWI8e8, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_Ic4aCLaa, 60000.0f);
  numBytes += cVar_init_f(&cVar_MNJyceZf, 500.0f);
  numBytes += cSlice_init(&cSlice_eb2sY5uw, 1, -1);
  numBytes += cSlice_init(&cSlice_JwGjCOQ2, 1, -1);
  numBytes += cVar_init_f(&cVar_ZDaOLlyU, 0.0f);
  numBytes += cIf_init(&cIf_2O3Y2VTn, false);
  numBytes += cBinop_init(&cBinop_xV8L0IVU, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_JaoQnoqx, 120.0f);
  numBytes += cBinop_init(&cBinop_kqUDvPDg, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_SdGd6fBH, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_cm5GRJhn, 60000.0f);
  numBytes += cVar_init_f(&cVar_PAF5ogTY, 500.0f);
  numBytes += cSlice_init(&cSlice_0UNdDdaB, 1, -1);
  numBytes += cSlice_init(&cSlice_MExpArSZ, 1, -1);
  numBytes += cVar_init_f(&cVar_ou2sB811, 0.0f);
  numBytes += cIf_init(&cIf_rYlrPk7o, false);
  numBytes += cBinop_init(&cBinop_Y4JLGdX0, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_1kQOeo2Y, 120.0f);
  numBytes += cBinop_init(&cBinop_7niSd2BZ, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_V8YXf1nC, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_OUeGviFG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_a29lGdHP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oTznAKkf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hfkmtLuX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8tUDUPrt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DsGmyjFe, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ttip5cdU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hEnjjWKg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AOH058z7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sYwVWEWn, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DL3Y::~Heavy_WSTD_DL3Y() {
  sEnv_free(&sEnv_pPlNAAca);
  sEnv_free(&sEnv_yvXQmYyh);
  sEnv_free(&sEnv_npDA7nk6);
  sEnv_free(&sEnv_AFkwDwwx);
  sEnv_free(&sEnv_OYV90pPc);
  sEnv_free(&sEnv_teB4zooV);
  hTable_free(&hTable_CWKOQWeU);
  hTable_free(&hTable_PGchTqhI);
  hTable_free(&hTable_0TAHHwZp);
  hTable_free(&hTable_2slfKaAf);
  hTable_free(&hTable_tsPDcfOd);
  hTable_free(&hTable_6gHb7SX0);
}

HvTable *Heavy_WSTD_DL3Y::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x29B74AF: return &hTable_CWKOQWeU; // del-1349-delayL
    case 0x19A00729: return &hTable_PGchTqhI; // del-1349-delayR
    case 0x584C8281: return &hTable_0TAHHwZp; // del-1428-delayL
    case 0x54BF59F6: return &hTable_2slfKaAf; // del-1428-delayR
    case 0xBCE693A: return &hTable_tsPDcfOd; // del-1507-delayL
    case 0x95A380B3: return &hTable_6gHb7SX0; // del-1507-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DL3Y::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_l5YlPANR_sendMessage);
      break;
    }
    case 0xBB584857: { // High_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vpJTibK7_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MfldQihN_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qIVQVJwp_sendMessage);
      break;
    }
    case 0xDD62B09F: { // High_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TR3SjFZe_sendMessage);
      break;
    }
    case 0xABB0CBCF: { // High_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wFyC7xJ8_sendMessage);
      break;
    }
    case 0xAE942A2: { // High_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5OjprXhm_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_P0rBhJPP_sendMessage);
      break;
    }
    case 0xA2D68920: { // Low_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gHhy1M9Q_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Vc64Ccxj_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_deqhjGaV_sendMessage);
      break;
    }
    case 0xFFFEE96: { // Low_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LdwJz6Pn_sendMessage);
      break;
    }
    case 0xA3BD8A20: { // Low_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_22Xwxn5F_sendMessage);
      break;
    }
    case 0x67F58CFB: { // Low_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YxOZKWCz_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6LNuIp7k_sendMessage);
      break;
    }
    case 0x59607D3: { // Mid_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MsUZcA8e_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bUnPoUf9_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mNPW0xqk_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xJWoTulK_sendMessage);
      break;
    }
    case 0x96E19510: { // Mid_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_d78OjRp6_sendMessage);
      break;
    }
    case 0xE1DB1774: { // Mid_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yC7TTC0X_sendMessage);
      break;
    }
    case 0xDB67B94E: { // Mid_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sdtm0r2g_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8iZnyDbT_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iaBtc92z_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XuqzZIq8_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EyUFn9HR_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0PhYcJuQ_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Q0XkogfL_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AZIaGbdA_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_36I8aJvo_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Splwcva7_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_K6m7ndzZ_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SpQMju7o_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_S7wx4BBf_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_j68hgm05_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_O8uxkEN1_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Bfe16qRz_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_U6QmyAOU_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AiONJNy3_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_i7GmvdGM_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qU52r1oc_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3DbQjhK8_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QAz1QfFU_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tD13uiYd_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_akKFT5zN_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fgiAS9DF_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_y0YtL7mR_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mUvvbtAT_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_abH5EQJO_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ftUe7eu9_sendMessage);
      break;
    }
    case 0x9FC1C9E5: { // 1349-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8NPlFAF1_sendMessage);
      break;
    }
    case 0x5D7BD4E9: { // 1349-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rddF7YSt_sendMessage);
      break;
    }
    case 0x371A347A: { // 1349-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EBjuxtS3_sendMessage);
      break;
    }
    case 0x810E74BC: { // 1349-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_z6VVibfw_sendMessage);
      break;
    }
    case 0xCC56B3CF: { // 1428-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fU0nJisv_sendMessage);
      break;
    }
    case 0x499A953B: { // 1428-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_H8N4ZzCi_sendMessage);
      break;
    }
    case 0xE0E7225B: { // 1428-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QsXtVNzS_sendMessage);
      break;
    }
    case 0xE6486F5F: { // 1428-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YtBpbUiv_sendMessage);
      break;
    }
    case 0xF65E8330: { // 1507-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OQgR9ls7_sendMessage);
      break;
    }
    case 0x3B8B5FB8: { // 1507-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GpVZMMNT_sendMessage);
      break;
    }
    case 0xE5F26E0D: { // 1507-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hTplozxz_sendMessage);
      break;
    }
    case 0xFDAB8735: { // 1507-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_I7S7dz8Q_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GEt2yPdK_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VBRaPX97_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DL3Y::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Cross";
        info->hash = 0xBB584857;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Sync";
        info->hash = 0xDD62B09F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "High_Time";
        info->hash = 0xABB0CBCF;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 6: {
        info->name = "High_TimeSync";
        info->hash = 0xAE942A2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 7: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low_Cross";
        info->hash = 0xA2D68920;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 9: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 10: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 11: {
        info->name = "Low_Sync";
        info->hash = 0xFFFEE96;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Time";
        info->hash = 0xA3BD8A20;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 13: {
        info->name = "Low_TimeSync";
        info->hash = 0x67F58CFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 14: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Cross";
        info->hash = 0x59607D3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 16: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Sync";
        info->hash = 0x96E19510;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Time";
        info->hash = 0xE1DB1774;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 21: {
        info->name = "Mid_TimeSync";
        info->hash = 0xDB67B94E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 22;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DL3Y::cVar_dR1uxmMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tVFx0Qn0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_HOgPLNOB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9GTKAFyP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_2V4smvIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0Wdran0e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_P0SMmeIA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Fcm6zj75_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WqiDkF0e_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WqtHFkQj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rOZFZhYx_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_exU0b1DR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UCws8fEV, 0, m, &cSlice_UCws8fEV_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Tlqfby5B_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_UCws8fEV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_bL1UieJP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_bL1UieJP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_zSd7KgEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bL1UieJP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_bL1UieJP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XuqzZIq8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Vs7HjouW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Pn4kySkW_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_vyNHhfgZ, 0, m, &cIf_vyNHhfgZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_vyNHhfgZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_PQyQ9pgp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_jWbnv0e1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Agl3tw9D_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_eRDcp2fw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_fKRPJbBI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gRmUmBKo, HV_BINOP_POW, 0, m, &cBinop_gRmUmBKo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gRmUmBKo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Gr4DBHhe, 0, m, &cIf_Gr4DBHhe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dJLObjCZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_LJTULMcX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_l0YdGQTJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jWbnv0e1, 0, m, &cIf_jWbnv0e1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yMizQyru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vYfTqwNJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vYfTqwNJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jWbnv0e1, 1, m, &cIf_jWbnv0e1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eRDcp2fw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_dJLObjCZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Agl3tw9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Gr4DBHhe, 0, m, &cIf_Gr4DBHhe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LJTULMcX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gRmUmBKo, HV_BINOP_POW, 1, m, &cBinop_gRmUmBKo_sendMessage);
  cMsg_fKRPJbBI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_Gr4DBHhe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_KZAOeiZd, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_Pn4kySkW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vyNHhfgZ, 1, m, &cIf_vyNHhfgZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PQyQ9pgp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1FOJt5be, HV_BINOP_GREATER_THAN, 1, m, &cBinop_1FOJt5be_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_am2HfGFf, HV_BINOP_EQ, 1, m, &cBinop_am2HfGFf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qdPDDJ7I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xoELwePg, HV_BINOP_ADD, 0, m, &cBinop_xoELwePg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xoELwePg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yMizQyru_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l0YdGQTJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1FOJt5be_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Gr4DBHhe, 1, m, &cIf_Gr4DBHhe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_am2HfGFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Cpyy5TBG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Cpyy5TBG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_KZAOeiZd, m);
}

void Heavy_WSTD_DL3Y::cCast_FVRyNwJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Vs7HjouW, 0, m, &cVar_Vs7HjouW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TPaBRAGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xoELwePg, HV_BINOP_ADD, 1, m, &cBinop_xoELwePg_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1FOJt5be, HV_BINOP_GREATER_THAN, 0, m, &cBinop_1FOJt5be_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_am2HfGFf, HV_BINOP_EQ, 0, m, &cBinop_am2HfGFf_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_E2EpjCiG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qdPDDJ7I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_w89zrCSU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_RNsvvqC1_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_PUlMyPbA, 0, m, &cIf_PUlMyPbA_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_PUlMyPbA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_1vKKqtiv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_2olS1ZDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_ygJRlxBz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_tHy7aU4A_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_OdNNafOM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Exlsvjdq, HV_BINOP_POW, 0, m, &cBinop_Exlsvjdq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Exlsvjdq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OwQwzorW, 0, m, &cIf_OwQwzorW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1bkrGgEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_DrQ6pgKv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_XkLDxxET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_7gm5B9Dc_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_oDUnl18V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2olS1ZDh, 0, m, &cIf_2olS1ZDh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7gm5B9Dc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2olS1ZDh, 1, m, &cIf_2olS1ZDh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tHy7aU4A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_1bkrGgEg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ygJRlxBz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_OwQwzorW, 0, m, &cIf_OwQwzorW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DrQ6pgKv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Exlsvjdq, HV_BINOP_POW, 1, m, &cBinop_Exlsvjdq_sendMessage);
  cMsg_OdNNafOM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_OwQwzorW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_QRP7qi03_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_zTy9nxWC_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_cNkul6WO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_RNsvvqC1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PUlMyPbA, 1, m, &cIf_PUlMyPbA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1vKKqtiv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JqtChIz4, HV_BINOP_GREATER_THAN, 1, m, &cBinop_JqtChIz4_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4jwm0jEF, HV_BINOP_EQ, 1, m, &cBinop_4jwm0jEF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZOyh8Wk9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WhGWBTpQ, HV_BINOP_ADD, 0, m, &cBinop_WhGWBTpQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WhGWBTpQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XkLDxxET_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oDUnl18V_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JqtChIz4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OwQwzorW, 1, m, &cIf_OwQwzorW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4jwm0jEF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JPwsbTKt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_JPwsbTKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_QRP7qi03_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_zTy9nxWC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_cNkul6WO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_s9ApuWQq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_w89zrCSU, 0, m, &cVar_w89zrCSU_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1EOygAtY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZOyh8Wk9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_lMeGc6TP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WhGWBTpQ, HV_BINOP_ADD, 1, m, &cBinop_WhGWBTpQ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JqtChIz4, HV_BINOP_GREATER_THAN, 0, m, &cBinop_JqtChIz4_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4jwm0jEF, HV_BINOP_EQ, 0, m, &cBinop_4jwm0jEF_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_4BBwMvBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_sQetRAMV_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_kzQOkk2i, 0, m, &cIf_kzQOkk2i_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_kzQOkk2i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_hpJrxy1J_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_zlsvrnkc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_mpet13Ks_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_askQ227I_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_06NFrekz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_l9ef4jlG, HV_BINOP_POW, 0, m, &cBinop_l9ef4jlG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_l9ef4jlG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_d8AXZUz4, 0, m, &cIf_d8AXZUz4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yn7IqR6o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_6ZEOtrpf_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9ObSAd7f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_uCjTSaxT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_po0pdrKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zlsvrnkc, 0, m, &cIf_zlsvrnkc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uCjTSaxT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zlsvrnkc, 1, m, &cIf_zlsvrnkc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_askQ227I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_yn7IqR6o_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mpet13Ks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_d8AXZUz4, 0, m, &cIf_d8AXZUz4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6ZEOtrpf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_l9ef4jlG, HV_BINOP_POW, 1, m, &cBinop_l9ef4jlG_sendMessage);
  cMsg_06NFrekz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_d8AXZUz4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_4KBeqg7p, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_sQetRAMV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kzQOkk2i, 1, m, &cIf_kzQOkk2i_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hpJrxy1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hNdhmpJ9, HV_BINOP_GREATER_THAN, 1, m, &cBinop_hNdhmpJ9_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_lOn9sP5b, HV_BINOP_EQ, 1, m, &cBinop_lOn9sP5b_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZczPad9m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZIBk7Lab, HV_BINOP_ADD, 0, m, &cBinop_ZIBk7Lab_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZIBk7Lab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9ObSAd7f_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_po0pdrKt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hNdhmpJ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_d8AXZUz4, 1, m, &cIf_d8AXZUz4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lOn9sP5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IrBe6wcR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_IrBe6wcR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_4KBeqg7p, m);
}

void Heavy_WSTD_DL3Y::cCast_NKLZegpH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4BBwMvBi, 0, m, &cVar_4BBwMvBi_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_mfV3Mjqp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZczPad9m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_nYOg2LHA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZIBk7Lab, HV_BINOP_ADD, 1, m, &cBinop_ZIBk7Lab_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_hNdhmpJ9, HV_BINOP_GREATER_THAN, 0, m, &cBinop_hNdhmpJ9_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_lOn9sP5b, HV_BINOP_EQ, 0, m, &cBinop_lOn9sP5b_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_m7pJWo7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_rtYFa6uk, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_hqK7WYuV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CP3C2UKq, 0, m, &cSlice_CP3C2UKq_sendMessage);
      break;
    }
    default: {
      cSwitchcase_gek8pRLY_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_CP3C2UKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qPUukJJM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qPUukJJM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_SN8ntG52_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qPUukJJM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_qPUukJJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8iZnyDbT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_gek8pRLY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GNpd6yoz, 0, m, &cSlice_GNpd6yoz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_exU0b1DR_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_GNpd6yoz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_tzpStGp0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_tzpStGp0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_JvN7CrtE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tzpStGp0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_tzpStGp0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0PhYcJuQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Tlqfby5B_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8pSBsGNA, 0, m, &cSlice_8pSBsGNA_sendMessage);
      break;
    }
    default: {
      cSwitchcase_BrSXaQO7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_8pSBsGNA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_20mRCzOn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_20mRCzOn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_fadgWOAN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_20mRCzOn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_20mRCzOn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_iaBtc92z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_BrSXaQO7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_RG8fjak9, 0, m, &cSlice_RG8fjak9_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_RG8fjak9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_HYy0udmf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_HYy0udmf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_LByYkg0G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HYy0udmf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_HYy0udmf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EyUFn9HR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Y5igl2sM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HfB8f7Kh, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_LnBhfmhK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_alTVnMXF, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_voRz9U9t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KwGtZbyF, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_rg4i2Ifd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Pd4be4B6, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_8jIXIIVS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KkIkFAF3, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_l3vCPlxs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8kBI7SZA_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_8kBI7SZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bjIXS2LI, HV_BINOP_DIVIDE, 1, m, &cBinop_bjIXS2LI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0TITGtjy_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_oFI6Bm9B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_supZpHCb_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cqyfNYqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_oFI6Bm9B_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_supZpHCb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bjIXS2LI, HV_BINOP_DIVIDE, 0, m, &cBinop_bjIXS2LI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0TITGtjy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cqyfNYqh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_bjIXS2LI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wR8w5VXe, HV_BINOP_MULTIPLY, 1, m, &cBinop_wR8w5VXe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wR8w5VXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zzBbVNJv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ETrdG9DH_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_I5t2Jnom_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SEpA098U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_dvEn2jW4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OIoMUIMz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_3eKALFcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_pZJnV7jP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pZJnV7jP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wR8w5VXe, HV_BINOP_MULTIPLY, 0, m, &cBinop_wR8w5VXe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MYfrQF8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_87L4tEV8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_87L4tEV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8s8088Un_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_lmIOuSqY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KHnbpNMG, 1, m, &cVar_KHnbpNMG_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_KHnbpNMG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0YtCps2Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_N5rJpI8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1TZEEhQX, HV_BINOP_MULTIPLY, 1, m, &cBinop_1TZEEhQX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qiMFx7OX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_N5rJpI8W_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_e1mPc1dk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_2nbCWJ7A_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2nbCWJ7A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Gbgi0Cd, HV_BINOP_MULTIPLY, 1, m, &cBinop_2Gbgi0Cd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3ynud90O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ay9M6sZF, HV_BINOP_MULTIPLY, 1, m, &cBinop_Ay9M6sZF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rAylZzAA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_3ynud90O_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9GxaB2GQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kD5eQe2d, HV_BINOP_MULTIPLY, 1, m, &cBinop_kD5eQe2d_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9f2vNcpZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_M9muFA65_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_M9muFA65_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CeoouEmv, HV_BINOP_MULTIPLY, 1, m, &cBinop_CeoouEmv_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_sHJen0hU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uLxCnzS8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_3eKALFcE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DNrsdqf7_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_p5zUw7jy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_MYfrQF8d_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ETrdG9DH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_dvEn2jW4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_zzBbVNJv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_I5t2Jnom_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_SEpA098U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_36I8aJvo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_OIoMUIMz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AZIaGbdA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_kJDljO7v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Q0XkogfL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_8s8088Un_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_eBb2QwZ3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eBb2QwZ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I14B8NfX, HV_BINOP_MULTIPLY, 1, m, &cBinop_I14B8NfX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_I14B8NfX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_FijKHpDn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FijKHpDn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kJDljO7v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_0YtCps2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_IC5vghYe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IC5vghYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_us36TMVm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_THPmH7nl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ee5pTlSF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gnJgxOeQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CdJHo1ah_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zFj7RFX9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1TZEEhQX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y5igl2sM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_2Gbgi0Cd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LnBhfmhK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Ay9M6sZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_voRz9U9t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_kD5eQe2d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rg4i2Ifd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_CeoouEmv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8jIXIIVS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_C1wiGldW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sHJen0hU, 0, m, &cVar_sHJen0hU_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_HBhlECwd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_p5zUw7jy, 1, m, &cVar_p5zUw7jy_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_gnJgxOeQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ay9M6sZF, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ay9M6sZF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_us36TMVm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_zFj7RFX9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1TZEEhQX, HV_BINOP_MULTIPLY, 0, m, &cBinop_1TZEEhQX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ee5pTlSF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kD5eQe2d, HV_BINOP_MULTIPLY, 0, m, &cBinop_kD5eQe2d_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CdJHo1ah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Gbgi0Cd, HV_BINOP_MULTIPLY, 0, m, &cBinop_2Gbgi0Cd_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_THPmH7nl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CeoouEmv, HV_BINOP_MULTIPLY, 0, m, &cBinop_CeoouEmv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_uLxCnzS8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_p5zUw7jy, 0, m, &cVar_p5zUw7jy_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DNrsdqf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KHnbpNMG, 0, m, &cVar_KHnbpNMG_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xtSuXvIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qoUDselp, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_dFV0pIfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vL3RoZiy, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_HlMoGA6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_scCwlgNL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_VtvYJ1ND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4heJ8ozW, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_qM6wHyOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_E9JXOBus_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_E9JXOBus_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LJQfpvo6, HV_BINOP_DIVIDE, 1, m, &cBinop_LJQfpvo6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YuWXmyYE_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_zQVFRaAE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_dvFIq7OX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ahS9eUJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_zQVFRaAE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dvFIq7OX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LJQfpvo6, HV_BINOP_DIVIDE, 0, m, &cBinop_LJQfpvo6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_YuWXmyYE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ahS9eUJB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_LJQfpvo6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tI0lFLl0, HV_BINOP_MULTIPLY, 1, m, &cBinop_tI0lFLl0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tI0lFLl0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4HgqD2d9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wNIGbGDo_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_p7R9igcf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YwY4PLWz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_KH4e8eOO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_k5yvwUvX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_d6CsccWs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_eB67z8JB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eB67z8JB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tI0lFLl0, HV_BINOP_MULTIPLY, 0, m, &cBinop_tI0lFLl0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dtgqg9AL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_zWwDQHVn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zWwDQHVn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KZKhfnHw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_nTGVsBLl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dZoRv71W, HV_BINOP_MULTIPLY, 1, m, &cBinop_dZoRv71W_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9SbzRVkH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TddxtTT8, 1, m, &cVar_TddxtTT8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OfgnMt4D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wMIhcTjO, HV_BINOP_MULTIPLY, 1, m, &cBinop_wMIhcTjO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_M0QwdOe8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_AExjyqgk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AExjyqgk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kg9n92fm, HV_BINOP_MULTIPLY, 1, m, &cBinop_kg9n92fm_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_TddxtTT8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a5E5k6OT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_gEoBKNm3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DMr2LpMd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_d6CsccWs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CpEaZrPS_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_eENrEEUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_dtgqg9AL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wNIGbGDo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_KH4e8eOO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4HgqD2d9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_p7R9igcf_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_YwY4PLWz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SpQMju7o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_k5yvwUvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_K6m7ndzZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_X1U8VOrk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Splwcva7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_KZKhfnHw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_EACOjgKx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EACOjgKx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k7cM7Nw0, HV_BINOP_MULTIPLY, 1, m, &cBinop_k7cM7Nw0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_k7cM7Nw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_rzYQt7EE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rzYQt7EE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_X1U8VOrk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_a5E5k6OT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_AkmgFzmV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AkmgFzmV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UnqEqUOJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0XzaiSQh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yVWXgNFm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jgR9JUwT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hQeeyKUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xtSuXvIV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_dZoRv71W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dFV0pIfs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_wMIhcTjO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HlMoGA6N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_kg9n92fm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VtvYJ1ND_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_yQ5FemQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gEoBKNm3, 0, m, &cVar_gEoBKNm3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_I0SwtZ2k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eENrEEUk, 1, m, &cVar_eENrEEUk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CpEaZrPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TddxtTT8, 0, m, &cVar_TddxtTT8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DMr2LpMd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eENrEEUk, 0, m, &cVar_eENrEEUk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jgR9JUwT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hQeeyKUi, HV_BINOP_MULTIPLY, 0, m, &cBinop_hQeeyKUi_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_UnqEqUOJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kg9n92fm, HV_BINOP_MULTIPLY, 0, m, &cBinop_kg9n92fm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yVWXgNFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dZoRv71W, HV_BINOP_MULTIPLY, 0, m, &cBinop_dZoRv71W_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0XzaiSQh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wMIhcTjO, HV_BINOP_MULTIPLY, 0, m, &cBinop_wMIhcTjO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PY4cxYuw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gjgZU9yb, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_xKQID5ID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_p3SPLn1E, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_3LHromp4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qzWRJBPU, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_jcu53HzA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Uxy0D7ls, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_GUN6myoO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_et3qMfIx, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ZooNLd4Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wb2MCm6E_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_wb2MCm6E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Tv2NyBcI, HV_BINOP_DIVIDE, 1, m, &cBinop_Tv2NyBcI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_00OfPMIG_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_Fyi26Oq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_G2RLM6rM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5x06t4GZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Fyi26Oq2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_G2RLM6rM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Tv2NyBcI, HV_BINOP_DIVIDE, 0, m, &cBinop_Tv2NyBcI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_00OfPMIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5x06t4GZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Tv2NyBcI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7C1tlPPz, HV_BINOP_MULTIPLY, 1, m, &cBinop_7C1tlPPz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7C1tlPPz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tv4GZNkU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tundB42h_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_jsIAJ4bl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hKvJ00J8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_0MIvRMfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AOVZ7Ses_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ProLf7RF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_u2CMMeg0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_u2CMMeg0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7C1tlPPz, HV_BINOP_MULTIPLY, 0, m, &cBinop_7C1tlPPz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ox4CdZDj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_LAyScAxl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LAyScAxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fO0V6wo7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Xyit5ALW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p3u0AOc3, HV_BINOP_MULTIPLY, 1, m, &cBinop_p3u0AOc3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9jvKafx7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_eZkRAAr7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eZkRAAr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Xyit5ALW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6Lubx88D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_9mJnsgu1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9mJnsgu1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QffQ4kiZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_QffQ4kiZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YLx4rh9R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oCNnkQPS, HV_BINOP_MULTIPLY, 1, m, &cBinop_oCNnkQPS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UwaNrMqg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_yQpKfgys_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yQpKfgys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_YLx4rh9R_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bh4UufRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7pMYfOEV, 1, m, &cVar_7pMYfOEV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pBaEofci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qQg8CeHn, HV_BINOP_MULTIPLY, 1, m, &cBinop_qQg8CeHn_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_sq5ssufF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_hCR5AwVR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hCR5AwVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0GrpSxPt, HV_BINOP_MULTIPLY, 1, m, &cBinop_0GrpSxPt_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_7pMYfOEV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O5X9wyE9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_RvuVwxs4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N2dTCfMG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_ProLf7RF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wnI9ZDXM_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_y8tzcqoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Ox4CdZDj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_tundB42h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_0MIvRMfK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_tv4GZNkU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_jsIAJ4bl_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_hKvJ00J8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_O8uxkEN1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_AOVZ7Ses_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_j68hgm05_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_xtOeFJ8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_S7wx4BBf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_fO0V6wo7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_sMw2ZM3J_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sMw2ZM3J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J5Ja3V6Q, HV_BINOP_MULTIPLY, 1, m, &cBinop_J5Ja3V6Q_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_J5Ja3V6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_WwuzIN5e_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WwuzIN5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xtOeFJ8L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_O5X9wyE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Zlgzwr8E_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Zlgzwr8E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f4ielyC8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6mURPSZj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dLZcBnP9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EBZCXAga_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oaDO8VOh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6vXVGgx3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_p3u0AOc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PY4cxYuw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_QffQ4kiZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xKQID5ID_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_oCNnkQPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3LHromp4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_qQg8CeHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jcu53HzA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_0GrpSxPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GUN6myoO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_6vIRN64Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RvuVwxs4, 0, m, &cVar_RvuVwxs4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_VSgIgeoH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_y8tzcqoY, 1, m, &cVar_y8tzcqoY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_oaDO8VOh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QffQ4kiZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_QffQ4kiZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6mURPSZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0GrpSxPt, HV_BINOP_MULTIPLY, 0, m, &cBinop_0GrpSxPt_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EBZCXAga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oCNnkQPS, HV_BINOP_MULTIPLY, 0, m, &cBinop_oCNnkQPS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_f4ielyC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_6vXVGgx3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p3u0AOc3, HV_BINOP_MULTIPLY, 0, m, &cBinop_p3u0AOc3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_dLZcBnP9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qQg8CeHn, HV_BINOP_MULTIPLY, 0, m, &cBinop_qQg8CeHn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wnI9ZDXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7pMYfOEV, 0, m, &cVar_7pMYfOEV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_N2dTCfMG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_y8tzcqoY, 0, m, &cVar_y8tzcqoY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QRP7qi03_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_m7pJWo7d, 1, m, &cIf_m7pJWo7d_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TOxHjCUN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_rtYFa6uk, m);
}

void Heavy_WSTD_DL3Y::cBinop_zTy9nxWC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TOxHjCUN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_cNkul6WO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_m7pJWo7d, 0, m, &cIf_m7pJWo7d_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_jrzVTJCT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_et00kSuF, 0, m, &cSlice_et00kSuF_sendMessage);
      break;
    }
    default: {
      cSwitchcase_pOfFqh4c_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_et00kSuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_sODUUHuZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_sODUUHuZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_wvrbnpa8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sODUUHuZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_sODUUHuZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AiONJNy3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_upfMbw8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Ucml7bqJ_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_uwQFxvhz, 0, m, &cIf_uwQFxvhz_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_uwQFxvhz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_e9z4HNFb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_Rxr6Q266_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_yLQlgLWv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_LnPXQw6h_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_GarATTzA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5L1rMkUE, HV_BINOP_POW, 0, m, &cBinop_5L1rMkUE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5L1rMkUE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hgoPQv1I, 0, m, &cIf_hgoPQv1I_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tUUvCNC0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_ZZiFVaOE_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_dPuv1doT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Rxr6Q266, 0, m, &cIf_Rxr6Q266_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nVHXfScc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_zP8LUuXf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zP8LUuXf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Rxr6Q266, 1, m, &cIf_Rxr6Q266_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LnPXQw6h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_tUUvCNC0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_yLQlgLWv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_hgoPQv1I, 0, m, &cIf_hgoPQv1I_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZZiFVaOE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5L1rMkUE, HV_BINOP_POW, 1, m, &cBinop_5L1rMkUE_sendMessage);
  cMsg_GarATTzA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_hgoPQv1I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_qVE7YLk9, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_Ucml7bqJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uwQFxvhz, 1, m, &cIf_uwQFxvhz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_e9z4HNFb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FqSHitcH, HV_BINOP_GREATER_THAN, 1, m, &cBinop_FqSHitcH_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_744J8DWQ, HV_BINOP_EQ, 1, m, &cBinop_744J8DWQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PkjcKfbV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_MpfPjbo8, HV_BINOP_ADD, 0, m, &cBinop_MpfPjbo8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MpfPjbo8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nVHXfScc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dPuv1doT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FqSHitcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hgoPQv1I, 1, m, &cIf_hgoPQv1I_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_744J8DWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oFjmnzn5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_oFjmnzn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_qVE7YLk9, m);
}

void Heavy_WSTD_DL3Y::cCast_C7yPvR6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PkjcKfbV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_2fVIiECc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MpfPjbo8, HV_BINOP_ADD, 1, m, &cBinop_MpfPjbo8_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_FqSHitcH, HV_BINOP_GREATER_THAN, 0, m, &cBinop_FqSHitcH_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_744J8DWQ, HV_BINOP_EQ, 0, m, &cBinop_744J8DWQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZOKe5o2B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_upfMbw8d, 0, m, &cVar_upfMbw8d_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Ag0p5hQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_gxdIFLrh_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Az0dmANw, 0, m, &cIf_Az0dmANw_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_Az0dmANw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_oQESvklc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_n4S8RFMw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_TXaOvH8S_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_SZtMl2HE_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_iVs0KIjt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1PNNKUPs, HV_BINOP_POW, 0, m, &cBinop_1PNNKUPs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1PNNKUPs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_REjXHOI1, 0, m, &cIf_REjXHOI1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Vo9i0Qbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_sSwnKGWL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_OvHTMGA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_U57dloB8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DnxNUJYr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n4S8RFMw, 0, m, &cIf_n4S8RFMw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_U57dloB8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n4S8RFMw, 1, m, &cIf_n4S8RFMw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SZtMl2HE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Vo9i0Qbl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TXaOvH8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_REjXHOI1, 0, m, &cIf_REjXHOI1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sSwnKGWL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1PNNKUPs, HV_BINOP_POW, 1, m, &cBinop_1PNNKUPs_sendMessage);
  cMsg_iVs0KIjt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_REjXHOI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_O5HcLyey_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_zqQFLErr_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_INv9ID7W_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_gxdIFLrh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Az0dmANw, 1, m, &cIf_Az0dmANw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oQESvklc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y7wv6WUA, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Y7wv6WUA_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_H79sxgMl, HV_BINOP_EQ, 1, m, &cBinop_H79sxgMl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YasN5yB4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JLWal8ZI, HV_BINOP_ADD, 0, m, &cBinop_JLWal8ZI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JLWal8ZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OvHTMGA0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DnxNUJYr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Y7wv6WUA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_REjXHOI1, 1, m, &cIf_REjXHOI1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_H79sxgMl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gh6tejUW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_gh6tejUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_O5HcLyey_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_zqQFLErr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_INv9ID7W_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hNBpG5Ou_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ag0p5hQn, 0, m, &cVar_Ag0p5hQn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Varg3UKY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YasN5yB4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_4hVpx9M8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JLWal8ZI, HV_BINOP_ADD, 1, m, &cBinop_JLWal8ZI_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y7wv6WUA, HV_BINOP_GREATER_THAN, 0, m, &cBinop_Y7wv6WUA_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_H79sxgMl, HV_BINOP_EQ, 0, m, &cBinop_H79sxgMl_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_E5yKBeIZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_GZS9CgTM_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_b7F2Z8fE, 0, m, &cIf_b7F2Z8fE_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_b7F2Z8fE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_QGSbIwwa_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_chOM2NfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_jc6QGIFK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_pNWYxTst_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_AagmWBZZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rfYtltWa, HV_BINOP_POW, 0, m, &cBinop_rfYtltWa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rfYtltWa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PF5JeXh9, 0, m, &cIf_PF5JeXh9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oRZcotKb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_zv1fdMOu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_AScKXRRi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_chOM2NfK, 0, m, &cIf_chOM2NfK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_w0rpNxyX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Jakb9oue_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Jakb9oue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_chOM2NfK, 1, m, &cIf_chOM2NfK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pNWYxTst_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_oRZcotKb_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jc6QGIFK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_PF5JeXh9, 0, m, &cIf_PF5JeXh9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zv1fdMOu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rfYtltWa, HV_BINOP_POW, 1, m, &cBinop_rfYtltWa_sendMessage);
  cMsg_AagmWBZZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_PF5JeXh9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_mqgeQyyS, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_GZS9CgTM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_b7F2Z8fE, 1, m, &cIf_b7F2Z8fE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QGSbIwwa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CaISUOkl, HV_BINOP_GREATER_THAN, 1, m, &cBinop_CaISUOkl_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yW7krlPp, HV_BINOP_EQ, 1, m, &cBinop_yW7krlPp_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_2aFD4qUy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8uTeeizN, HV_BINOP_ADD, 0, m, &cBinop_8uTeeizN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8uTeeizN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_w0rpNxyX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AScKXRRi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CaISUOkl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PF5JeXh9, 1, m, &cIf_PF5JeXh9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yW7krlPp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VKaNDGad_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_VKaNDGad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_mqgeQyyS, m);
}

void Heavy_WSTD_DL3Y::cCast_jcAoC2B6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2aFD4qUy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_lEY0KVXg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8uTeeizN, HV_BINOP_ADD, 1, m, &cBinop_8uTeeizN_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CaISUOkl, HV_BINOP_GREATER_THAN, 0, m, &cBinop_CaISUOkl_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yW7krlPp, HV_BINOP_EQ, 0, m, &cBinop_yW7krlPp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ggJqxS9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_E5yKBeIZ, 0, m, &cVar_E5yKBeIZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_ncY9ugct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_YwcIDpxR, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_h8mVwoAk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_w4dx3eAl, 0, m, &cSlice_w4dx3eAl_sendMessage);
      break;
    }
    default: {
      cSwitchcase_8Ica5LG2_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_w4dx3eAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_vqMM7G7R_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_vqMM7G7R_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_s39Iwr0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vqMM7G7R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_vqMM7G7R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Bfe16qRz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_8Ica5LG2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9gONzQrt, 0, m, &cSlice_9gONzQrt_sendMessage);
      break;
    }
    default: {
      cSwitchcase_jrzVTJCT_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_9gONzQrt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GBXa4P9t_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GBXa4P9t_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_2RamqhcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GBXa4P9t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_GBXa4P9t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qU52r1oc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_pOfFqh4c_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_sLOd3ZWw, 0, m, &cSlice_sLOd3ZWw_sendMessage);
      break;
    }
    default: {
      cSwitchcase_EsuCtH6O_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_sLOd3ZWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_OKEQsqrI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_OKEQsqrI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_BmO7BZOM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OKEQsqrI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_OKEQsqrI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_U6QmyAOU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_EsuCtH6O_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ifE1xjM2, 0, m, &cSlice_ifE1xjM2_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_ifE1xjM2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_AaYRCBvx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_AaYRCBvx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_TV64yr9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AaYRCBvx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_AaYRCBvx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_i7GmvdGM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_uXHUrSwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_buIO0R4L, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_IX6FYVfb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BmUcqCOC, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_T9S3Wj70_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PBY1jd7q, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_uTqwqOTR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vuzcBGAp, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_p9e2QEie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UwBlNfmI, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_jChOZhxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_s4gfx9Xf_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_s4gfx9Xf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fDxbOX4K, HV_BINOP_DIVIDE, 1, m, &cBinop_fDxbOX4K_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ltJMLx3l_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_Lty8EEqL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_pOzKuBYC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_P1VANcKR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Lty8EEqL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pOzKuBYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fDxbOX4K, HV_BINOP_DIVIDE, 0, m, &cBinop_fDxbOX4K_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ltJMLx3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P1VANcKR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_fDxbOX4K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DS554yI0, HV_BINOP_MULTIPLY, 1, m, &cBinop_DS554yI0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DS554yI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1wJsElb1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_G0ZZ9TxX_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_3qpNJW1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_s6EQDZnZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_3yy1BLXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wwOG9vQn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_3umKmjJI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_XoYLc1De_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XoYLc1De_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DS554yI0, HV_BINOP_MULTIPLY, 0, m, &cBinop_DS554yI0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GE7AQZTx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_VWoRz4D0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VWoRz4D0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_378qFFsw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ldnGpjLm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_D1HbT1nf, 1, m, &cVar_D1HbT1nf_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_D1HbT1nf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Gv0jVrND_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ri43cL1Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DPr61eEg, HV_BINOP_MULTIPLY, 1, m, &cBinop_DPr61eEg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8woAAECK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ri43cL1Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RtzEMrwe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_A7yLVYgo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_A7yLVYgo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vomD4SLS, HV_BINOP_MULTIPLY, 1, m, &cBinop_vomD4SLS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LHvlOJMn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TWi2RUE4, HV_BINOP_MULTIPLY, 1, m, &cBinop_TWi2RUE4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_27yKdsU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_LHvlOJMn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_La97wcfh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WdAI0PIu, HV_BINOP_MULTIPLY, 1, m, &cBinop_WdAI0PIu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vBYRR3Zu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_x1fMu0uC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_x1fMu0uC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L4TI6tWB, HV_BINOP_MULTIPLY, 1, m, &cBinop_L4TI6tWB_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_qik2bFSf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ubq8j8NN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_3umKmjJI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JAzFDH0j_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_gCJbLTCZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_GE7AQZTx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_G0ZZ9TxX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_3yy1BLXO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1wJsElb1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_3qpNJW1l_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_s6EQDZnZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tD13uiYd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_wwOG9vQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QAz1QfFU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_I3VtgKc0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3DbQjhK8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_378qFFsw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_oDdaUUXy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oDdaUUXy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rT9T5ggx, HV_BINOP_MULTIPLY, 1, m, &cBinop_rT9T5ggx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rT9T5ggx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_kon2qEXl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kon2qEXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_I3VtgKc0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Gv0jVrND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_L08RfsIF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_L08RfsIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kp6WAoFa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LadWlCNe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6qkF7I3W_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Jm9cotNz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3MZHhDgE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SxQo5Lcp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DPr61eEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uXHUrSwN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_vomD4SLS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IX6FYVfb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_TWi2RUE4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T9S3Wj70_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_WdAI0PIu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uTqwqOTR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_L4TI6tWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p9e2QEie_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_BmfZi1xR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gCJbLTCZ, 1, m, &cVar_gCJbLTCZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CBwGoI5i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qik2bFSf, 0, m, &cVar_qik2bFSf_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SxQo5Lcp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DPr61eEg, HV_BINOP_MULTIPLY, 0, m, &cBinop_DPr61eEg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6qkF7I3W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WdAI0PIu, HV_BINOP_MULTIPLY, 0, m, &cBinop_WdAI0PIu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3MZHhDgE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vomD4SLS, HV_BINOP_MULTIPLY, 0, m, &cBinop_vomD4SLS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LadWlCNe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L4TI6tWB, HV_BINOP_MULTIPLY, 0, m, &cBinop_L4TI6tWB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Jm9cotNz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TWi2RUE4, HV_BINOP_MULTIPLY, 0, m, &cBinop_TWi2RUE4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_kp6WAoFa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_JAzFDH0j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_D1HbT1nf, 0, m, &cVar_D1HbT1nf_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ubq8j8NN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gCJbLTCZ, 0, m, &cVar_gCJbLTCZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BGWljxZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eo17yxQ0, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_2uXuXWw7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jnZrF0HV, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_VW80pEzX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_urFMGpSK, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_NrEeEX4l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cayeb2i8, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_UShumYBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CJbOhZLv_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_CJbOhZLv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_05Kpl9Je, HV_BINOP_DIVIDE, 1, m, &cBinop_05Kpl9Je_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EBYZhDth_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_Xe2zLJEK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_OvbycH4U_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XM9VLpDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Xe2zLJEK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OvbycH4U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_05Kpl9Je, HV_BINOP_DIVIDE, 0, m, &cBinop_05Kpl9Je_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EBYZhDth_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XM9VLpDs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_05Kpl9Je_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eItUCOwA, HV_BINOP_MULTIPLY, 1, m, &cBinop_eItUCOwA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eItUCOwA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fPhfNg5M_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rAvU2hkE_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_PH6vkDLQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NdGqqrUX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_sii1jl0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dU9t5Bno_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_LYvLXzQq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_LTi6wGxd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LTi6wGxd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eItUCOwA, HV_BINOP_MULTIPLY, 0, m, &cBinop_eItUCOwA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GKIa0v0F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_RpowC7TB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RpowC7TB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7BCf7VmK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_gIse6nGo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U26RlsTl, HV_BINOP_MULTIPLY, 1, m, &cBinop_U26RlsTl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0qyon56E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UCEpO21g, 1, m, &cVar_UCEpO21g_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UQKIw3Q6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rRPHMexo, HV_BINOP_MULTIPLY, 1, m, &cBinop_rRPHMexo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_R9sK9mtr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_2aG4mJvk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2aG4mJvk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PiNHBtZR, HV_BINOP_MULTIPLY, 1, m, &cBinop_PiNHBtZR_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_UCEpO21g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Wd9WXgIS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_cNnpjLqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BUOzTXoY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_LYvLXzQq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nXm2WxvO_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_mMpE4Hcl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_GKIa0v0F_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rAvU2hkE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_sii1jl0K_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fPhfNg5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_PH6vkDLQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_NdGqqrUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_y0YtL7mR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_dU9t5Bno_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fgiAS9DF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_pSt6anXn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_akKFT5zN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_7BCf7VmK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_9hZTmPrk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9hZTmPrk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rH3uiKi9, HV_BINOP_MULTIPLY, 1, m, &cBinop_rH3uiKi9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rH3uiKi9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_uzNWu6N0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uzNWu6N0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pSt6anXn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Wd9WXgIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ual187f0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ual187f0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XWqFx1QI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_K8Lcpm8P_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uMz1x6V7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jwqwpWyY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vpGVGSxu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BGWljxZl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_U26RlsTl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2uXuXWw7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_rRPHMexo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VW80pEzX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_PiNHBtZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NrEeEX4l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_dursrFMV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cNnpjLqv, 0, m, &cVar_cNnpjLqv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_BpY8d0GA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mMpE4Hcl, 1, m, &cVar_mMpE4Hcl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nXm2WxvO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UCEpO21g, 0, m, &cVar_UCEpO21g_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_BUOzTXoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mMpE4Hcl, 0, m, &cVar_mMpE4Hcl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jwqwpWyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vpGVGSxu, HV_BINOP_MULTIPLY, 0, m, &cBinop_vpGVGSxu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_XWqFx1QI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PiNHBtZR, HV_BINOP_MULTIPLY, 0, m, &cBinop_PiNHBtZR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_uMz1x6V7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U26RlsTl, HV_BINOP_MULTIPLY, 0, m, &cBinop_U26RlsTl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_K8Lcpm8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rRPHMexo, HV_BINOP_MULTIPLY, 0, m, &cBinop_rRPHMexo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1hgjyTfq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WGibibhE, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Y41t2AXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_G6gOMWzu, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_TW5PJ8GT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zQ2Y2qt8, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_OjcuGdVG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vPZYf5m3, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_qwf8GDFO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XTkMygb3, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_fb5fjYVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_DuXfHP2T_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_DuXfHP2T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R9ZX6okM, HV_BINOP_DIVIDE, 1, m, &cBinop_R9ZX6okM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C5zFWKGw_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_Av1uEBg8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_IAAdUxJT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zucR8GSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Av1uEBg8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IAAdUxJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R9ZX6okM, HV_BINOP_DIVIDE, 0, m, &cBinop_R9ZX6okM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_C5zFWKGw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zucR8GSr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_R9ZX6okM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EiwMSuUc, HV_BINOP_MULTIPLY, 1, m, &cBinop_EiwMSuUc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EiwMSuUc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Y6Uevl1d_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Vlt4xIlg_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_0ByBwQGc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nT9GNiNc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_TddDJWUH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NrjNy1Hv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_BIkHR6KZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_kocGTQI9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kocGTQI9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EiwMSuUc, HV_BINOP_MULTIPLY, 0, m, &cBinop_EiwMSuUc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vcWqCxjz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_LSTDnxs7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LSTDnxs7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_61bo1f2R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_7Uo4PBgE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jrm888Ni, HV_BINOP_MULTIPLY, 1, m, &cBinop_Jrm888Ni_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gMVjlnhU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_DZbFTZK9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DZbFTZK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7Uo4PBgE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gn63aBNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rLWMIbSI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rLWMIbSI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rnJ0gMFW, HV_BINOP_MULTIPLY, 1, m, &cBinop_rnJ0gMFW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mBy1qyNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A92DpLFs, HV_BINOP_MULTIPLY, 1, m, &cBinop_A92DpLFs_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_HhirfhE1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_FfVDutKU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FfVDutKU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_mBy1qyNh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yFsE1NCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uXVxHb7v, 1, m, &cVar_uXVxHb7v_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zJWDCsrN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P7Sl1rFY, HV_BINOP_MULTIPLY, 1, m, &cBinop_P7Sl1rFY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0ibGG6L4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_yx1TyOTZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yx1TyOTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZC8lge5C, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZC8lge5C_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_uXVxHb7v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5U0UZpsS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_PoIJfAbL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kGoBhmmE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_BIkHR6KZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C9BnG74A_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Bk6hMwby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_vcWqCxjz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Y6Uevl1d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_0ByBwQGc_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Vlt4xIlg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_TddDJWUH_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_nT9GNiNc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ftUe7eu9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_NrjNy1Hv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_abH5EQJO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_Ettuw6za_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mUvvbtAT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_61bo1f2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_rswZ4sDk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rswZ4sDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7VQ7E3hh, HV_BINOP_MULTIPLY, 1, m, &cBinop_7VQ7E3hh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7VQ7E3hh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_l7dABro0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_l7dABro0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Ettuw6za_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_5U0UZpsS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ej17eY46_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ej17eY46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4xMdXLA6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bHBSIwrq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xBBcwurx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1Nzxj5yZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6zsQHJdm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9xZluS2z_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Jrm888Ni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1hgjyTfq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_rnJ0gMFW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y41t2AXM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_A92DpLFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TW5PJ8GT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_P7Sl1rFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OjcuGdVG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ZC8lge5C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qwf8GDFO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Sa9lP3iZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PoIJfAbL, 0, m, &cVar_PoIJfAbL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_iofndfaa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Bk6hMwby, 1, m, &cVar_Bk6hMwby_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6zsQHJdm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rnJ0gMFW, HV_BINOP_MULTIPLY, 0, m, &cBinop_rnJ0gMFW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bHBSIwrq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZC8lge5C, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZC8lge5C_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1Nzxj5yZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A92DpLFs, HV_BINOP_MULTIPLY, 0, m, &cBinop_A92DpLFs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4xMdXLA6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_9xZluS2z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jrm888Ni, HV_BINOP_MULTIPLY, 0, m, &cBinop_Jrm888Ni_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xBBcwurx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P7Sl1rFY, HV_BINOP_MULTIPLY, 0, m, &cBinop_P7Sl1rFY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_C9BnG74A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uXVxHb7v, 0, m, &cVar_uXVxHb7v_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_kGoBhmmE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Bk6hMwby, 0, m, &cVar_Bk6hMwby_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_O5HcLyey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ncY9ugct, 1, m, &cIf_ncY9ugct_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_2hLM69DX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_YwcIDpxR, m);
}

void Heavy_WSTD_DL3Y::cBinop_zqQFLErr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2hLM69DX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_INv9ID7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ncY9ugct, 0, m, &cIf_ncY9ugct_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_O04QjTib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2lrXHtiG, HV_BINOP_DIVIDE, 0, m, &cBinop_2lrXHtiG_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_S6IaTj51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KjK6GGBC, HV_BINOP_DIVIDE, 1, m, &cBinop_KjK6GGBC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2lrXHtiG, HV_BINOP_DIVIDE, 1, m, &cBinop_2lrXHtiG_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_Kg75cewZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ygr3D9fz, HV_BINOP_DIVIDE, 0, m, &cBinop_Ygr3D9fz_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_uqMYKWdw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ygr3D9fz, HV_BINOP_DIVIDE, 1, m, &cBinop_Ygr3D9fz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_WqiDkF0e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_S6IaTj51, 0, m, &cVar_S6IaTj51_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rOZFZhYx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KjK6GGBC, HV_BINOP_DIVIDE, 0, m, &cBinop_KjK6GGBC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_WqtHFkQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_O04QjTib, 0, m, &cVar_O04QjTib_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KjK6GGBC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_Kg75cewZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2lrXHtiG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_uqMYKWdw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ygr3D9fz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_qkvFhW4i_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_PXThYTx9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_n1WpbwTn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SgEmrrvd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_pi8Gk5Oh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qkvFhW4i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_SgEmrrvd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pi8Gk5Oh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_PXThYTx9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_n1WpbwTn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7IGJTXdH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_pGbZ12Ub_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eKAm7rRs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_FnTzIX64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f0iQ5aaQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_2E47ak7X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aNyOFAZX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_aS3Gdal4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oQJ6xizy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_GhbHQAux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3uUv1Xe6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_31jiv2pb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rlOEb2Hm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_ewGwOSBS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iAAlP2pS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_kIU4E1gb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_arbXmFFs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_FUWa9NDu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KaIXUeCl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_9KO4oCea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gxl8Glqp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_XtqshasM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NWJAphDO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_pxPuCY2V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vXkvmzSW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_HbIvfqeA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rAh6N8hu, 0, m, &cSlice_rAh6N8hu_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_rAh6N8hu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_4iviosNk_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_4iviosNk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_7dIGjUJA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4iviosNk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_4iviosNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EBjuxtS3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_QzGbkL4B_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_QQTSyAvt, 0, m, &cSlice_QQTSyAvt_sendMessage);
      break;
    }
    default: {
      cSwitchcase_WG6QFv8x_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_QQTSyAvt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_SFOQhEjb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_SFOQhEjb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_Oi0aItS1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SFOQhEjb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_SFOQhEjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8NPlFAF1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_JDnjj5xW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_10pkpCEA, 0, m, &cSlice_10pkpCEA_sendMessage);
      break;
    }
    default: {
      cSwitchcase_HbIvfqeA_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_10pkpCEA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_FJQvgaeo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_FJQvgaeo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_tfZoSHmm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FJQvgaeo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_FJQvgaeo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_z6VVibfw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_UewITmOC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_MYw5Us0J_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MYw5Us0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_26wGkfE3_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_SBPYaezI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CzA5aNcD_sendMessage(_c, 0, m);
  cMsg_Wi3IpRcZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_kMcPi9cv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xALGukmt_sendMessage(_c, 0, m);
  cMsg_diLtVqpP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_26wGkfE3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_FSvb8iLB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FSvb8iLB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DRyPf5FS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nFjHY6aZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DRyPf5FS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_JS87OUve_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nFjHY6aZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c4E2PCgV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_JS87OUve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_4C8Zm6q8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_c4E2PCgV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_RbIVpCTf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RbIVpCTf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Vl1fn5ZE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4C8Zm6q8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_SBPYaezI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Vl1fn5ZE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_kMcPi9cv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vnxZHux1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_yiAP11va_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yiAP11va_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_zazcmWJD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zazcmWJD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_RSgO1OqJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RSgO1OqJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_K4ddBC3M_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lDttoPeL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_K4ddBC3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_d39zceX9_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_lDttoPeL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9NmwH6tc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_d39zceX9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_tPVZoJ86_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9NmwH6tc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HC9TdSVI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HC9TdSVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_sokG4111_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sokG4111_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gGqXlW37_sendMessage(_c, 0, m);
  cMsg_4Aq3y9IE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_tPVZoJ86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jksysf7y_sendMessage(_c, 0, m);
  cMsg_eZyJ2kYe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_PWNo3s8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_kZ8VDBAI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kZ8VDBAI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ow6j4DeY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_IwElNGnh_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_9be1RhPi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_AmMFPqOP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_E21JjdkY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jNL15cOU_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_jNL15cOU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6ov4kNwK, HV_BINOP_DIVIDE, 1, m, &cBinop_6ov4kNwK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ow6j4DeY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_rfXKcGrX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rfXKcGrX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_BfTPhOAN, m);
}

void Heavy_WSTD_DL3Y::cMsg_WIMcgg7L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_haH7V8bQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_haH7V8bQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_PWNo3s8u_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IwElNGnh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_8GC5h7Mw, m);
}

void Heavy_WSTD_DL3Y::cBinop_AmMFPqOP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_gbc0bazV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gbc0bazV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6ov4kNwK, HV_BINOP_DIVIDE, 0, m, &cBinop_6ov4kNwK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6ov4kNwK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WIMcgg7L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_SZbIO57N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_w0SiFz9d_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_w0SiFz9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_1EyYepgc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_EMRKGQhl_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_KVhsrcX9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_DStajsfM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dcZvognO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Qh6GcKHh_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Qh6GcKHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MkkIsRzv, HV_BINOP_DIVIDE, 1, m, &cBinop_MkkIsRzv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1EyYepgc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_8MToua3Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8MToua3Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_3jG7cdfA, m);
}

void Heavy_WSTD_DL3Y::cMsg_aRwFJXZy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_xZhCbijL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xZhCbijL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_SZbIO57N_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EMRKGQhl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_SUO9eorV, m);
}

void Heavy_WSTD_DL3Y::cBinop_DStajsfM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_zUUXnBic_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zUUXnBic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MkkIsRzv, HV_BINOP_DIVIDE, 0, m, &cBinop_MkkIsRzv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MkkIsRzv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aRwFJXZy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_vhgz510u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wRVNK4hk, HV_BINOP_MULTIPLY, 0, m, &cBinop_wRVNK4hk_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_S0vYUkfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9ZUevLFJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_9ZUevLFJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uhVweF1g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_wRVNK4hk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_fGxN2W4p_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BVuR84eQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wRVNK4hk, HV_BINOP_MULTIPLY, 1, m, &cBinop_wRVNK4hk_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uhVweF1g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_BVuR84eQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fGxN2W4p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_2fWBHmE0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2fWBHmE0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_NfXmDZGn_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_4sTvt7Sf, m);
}

void Heavy_WSTD_DL3Y::cBinop_NfXmDZGn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_yYKnDHh0, m);
}

void Heavy_WSTD_DL3Y::cVar_50erY1lu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SIoYPrv1, HV_BINOP_MULTIPLY, 0, m, &cBinop_SIoYPrv1_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_sDM3Nrk4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CDwbTGMh_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_CDwbTGMh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SvZSRc7p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_SIoYPrv1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_6xiHgHcW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pJKixGGT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SIoYPrv1, HV_BINOP_MULTIPLY, 1, m, &cBinop_SIoYPrv1_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SvZSRc7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_pJKixGGT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6xiHgHcW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ujG57r8N_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ujG57r8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_NGu6M14s_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_MGowtGG9, m);
}

void Heavy_WSTD_DL3Y::cBinop_NGu6M14s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_HCMyTsDp, m);
}

void Heavy_WSTD_DL3Y::sEnv_pPlNAAca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Us7GjStS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M3oq3Uht_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_ly2CpDa5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_hpYzj0SA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_tEvwiIF6_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_DlUeUE5q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_nR0FVgjn, HV_BINOP_POW, 0, m, &cBinop_nR0FVgjn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nR0FVgjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xwCOrhl0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_RoXodzVt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_bGeaNp5M_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Us7GjStS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_eqAb5uIU_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_M3oq3Uht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ly2CpDa5, 0, m, &cIf_ly2CpDa5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eqAb5uIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ly2CpDa5, 1, m, &cIf_ly2CpDa5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tEvwiIF6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_RoXodzVt_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hpYzj0SA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_xwCOrhl0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_bGeaNp5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nR0FVgjn, HV_BINOP_POW, 1, m, &cBinop_nR0FVgjn_sendMessage);
  cMsg_DlUeUE5q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_OI6Ec8Ao_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_anfLNbIv, HV_BINOP_MULTIPLY, 0, m, &cBinop_anfLNbIv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PRtjYlTE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Klf9ImyM_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Klf9ImyM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6AttUKH8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_anfLNbIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ZuJTnbAH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NJ6BI9fn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_anfLNbIv, HV_BINOP_MULTIPLY, 1, m, &cBinop_anfLNbIv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6AttUKH8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_NJ6BI9fn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZuJTnbAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_XbiJKmWS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XbiJKmWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_eervQVBb_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_SeSclvrj, m);
}

void Heavy_WSTD_DL3Y::cBinop_eervQVBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ybMNApE6, m);
}

void Heavy_WSTD_DL3Y::cMsg_xwCOrhl0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_u1u8Qg5C_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_u1u8Qg5C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_QlwrnJpB, m);
}

void Heavy_WSTD_DL3Y::sEnv_yvXQmYyh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zvuyABDa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DQ8ogjjr_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_JPXDaEub_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_rEcAokKd_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_ltgIsVlZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_yWsYlpfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_la2P2sez, HV_BINOP_POW, 0, m, &cBinop_la2P2sez_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_la2P2sez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_U9dbflHU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_NJoQShGL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Cn1WI8vf_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_zvuyABDa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wuZ1MJaL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DQ8ogjjr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JPXDaEub, 0, m, &cIf_JPXDaEub_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wuZ1MJaL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JPXDaEub, 1, m, &cIf_JPXDaEub_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ltgIsVlZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_NJoQShGL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rEcAokKd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_U9dbflHU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Cn1WI8vf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_la2P2sez, HV_BINOP_POW, 1, m, &cBinop_la2P2sez_sendMessage);
  cMsg_yWsYlpfs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_MsxTifPA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JIj5hQQJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_JIj5hQQJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NoJnST5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oxGkudAp_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_oxGkudAp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OxBSsCeI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_JIj5hQQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_nJs3Vaqq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dhMbfKE5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JIj5hQQJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_JIj5hQQJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OxBSsCeI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_dhMbfKE5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nJs3Vaqq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_V8sXCTWV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_V8sXCTWV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_VJat9f7q_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_JqnFYYDH, m);
}

void Heavy_WSTD_DL3Y::cBinop_VJat9f7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_hEgBI23K, m);
}

void Heavy_WSTD_DL3Y::cMsg_U9dbflHU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_odVJoSN9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_odVJoSN9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_93erCWOz, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_WG6QFv8x_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PbOPyTPJ, 0, m, &cSlice_PbOPyTPJ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_JDnjj5xW_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_PbOPyTPJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_joqWjcNF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_joqWjcNF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_C8dCOkNW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_joqWjcNF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_joqWjcNF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rddF7YSt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Z8s9xUCu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_LiLb7K0d_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_LiLb7K0d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_hgw9Nvd1_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_ohm7Vapg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ohm7Vapg, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZFOJhjha, 0, m, &cDelay_ZFOJhjha_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ohm7Vapg, 0, m, &cDelay_ohm7Vapg_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_FZBcJac7, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_ZFOJhjha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZFOJhjha, m);
  cMsg_gr4MVI4D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_q1oX9a8r_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_vy58XSnS_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_Cunx2eaQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pGlJaQSx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_CWKOQWeU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uHwkGZar_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ohm7Vapg, 2, m, &cDelay_ohm7Vapg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PZqD3J9n_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pGlJaQSx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_CWKOQWeU, 0, m, &hTable_CWKOQWeU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hgw9Nvd1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_Cunx2eaQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gr4MVI4D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_CWKOQWeU, 0, m, &hTable_CWKOQWeU_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_PZqD3J9n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ohm7Vapg, 0, m, &cDelay_ohm7Vapg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uHwkGZar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZFOJhjha, 2, m, &cDelay_ZFOJhjha_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vy58XSnS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_FZBcJac7, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_501pHXEM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gCxVAou9, HV_BINOP_SUBTRACT, 0, m, &cBinop_gCxVAou9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SZrlXFXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_REkhbcjM_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_REkhbcjM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_tSc9sEdR_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_FDcNsqkJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CLBRSwSk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_PLKoGgG8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PLKoGgG8, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_r4rwnNsE, 0, m, &cDelay_r4rwnNsE_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_F22A441M, 0, m, &sTabread_F22A441M_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_r4rwnNsE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_r4rwnNsE, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_F22A441M, 0, m, &sTabread_F22A441M_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_r4rwnNsE, 0, m, &cDelay_r4rwnNsE_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_F22A441M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_0niCtFHR, HV_BINOP_SUBTRACT, 0, m, &cBinop_0niCtFHR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_QiKoG0dW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VD927jGG, HV_BINOP_MAX, 0, m, &cBinop_VD927jGG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tSc9sEdR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QiKoG0dW, HV_BINOP_MULTIPLY, 0, m, &cBinop_QiKoG0dW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gCxVAou9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5LqKzm3F_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_F22A441M, 0, m, &sTabread_F22A441M_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vADCkn6l_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_PWDX2R9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0niCtFHR, HV_BINOP_SUBTRACT, 1, m, &cBinop_0niCtFHR_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_r4rwnNsE, 2, m, &cDelay_r4rwnNsE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CLBRSwSk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PWDX2R9D_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5LqKzm3F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_PLKoGgG8, 0, m, &cDelay_PLKoGgG8_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_r4rwnNsE, 0, m, &cDelay_r4rwnNsE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_aLYqleZw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_VD927jGG, HV_BINOP_MAX, 1, m, &cBinop_VD927jGG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VD927jGG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gCxVAou9, HV_BINOP_SUBTRACT, 1, m, &cBinop_gCxVAou9_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vADCkn6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PLKoGgG8, 0, m, &cDelay_PLKoGgG8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SiGs43Ms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PLKoGgG8, 2, m, &cDelay_PLKoGgG8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0niCtFHR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_SiGs43Ms_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8BB334gL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FDcNsqkJ, 0, m, &cVar_FDcNsqkJ_sendMessage);
  cMsg_SZrlXFXd_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_501pHXEM, 0, m, &cTabhead_501pHXEM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_I6vpCizT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9UMQWgCM_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_9UMQWgCM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_lMzmsjez_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_4pPePPrr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4pPePPrr, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1EkWKoRl, 0, m, &cDelay_1EkWKoRl_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_4pPePPrr, 0, m, &cDelay_4pPePPrr_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_a5QJ4eun, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_1EkWKoRl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1EkWKoRl, m);
  cMsg_RHeXquEB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_iLuCb4J5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ZNwKkZ0k_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_TzUgHYJL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xgPnhV6c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_PGchTqhI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7TQG9bAi_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_4pPePPrr, 2, m, &cDelay_4pPePPrr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dnKusXfD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xgPnhV6c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_PGchTqhI, 0, m, &hTable_PGchTqhI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lMzmsjez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_TzUgHYJL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RHeXquEB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_PGchTqhI, 0, m, &hTable_PGchTqhI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_dnKusXfD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4pPePPrr, 0, m, &cDelay_4pPePPrr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7TQG9bAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_1EkWKoRl, 2, m, &cDelay_1EkWKoRl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZNwKkZ0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_a5QJ4eun, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_qNTM3jpW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2HDkYwCr, HV_BINOP_SUBTRACT, 0, m, &cBinop_2HDkYwCr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZSCsaUV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_982TXKOf_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_982TXKOf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_jy7WIMUP_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_1t0kq9gj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MwkPwpho_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_CDLF9W4D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CDLF9W4D, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ICfK9pAR, 0, m, &cDelay_ICfK9pAR_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_qvGLJlfv, 0, m, &sTabread_qvGLJlfv_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_ICfK9pAR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ICfK9pAR, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_qvGLJlfv, 0, m, &sTabread_qvGLJlfv_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ICfK9pAR, 0, m, &cDelay_ICfK9pAR_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_qvGLJlfv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_mIttT3ys, HV_BINOP_SUBTRACT, 0, m, &cBinop_mIttT3ys_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_xEPyIa8F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v4voNlRW, HV_BINOP_MAX, 0, m, &cBinop_v4voNlRW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jy7WIMUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xEPyIa8F, HV_BINOP_MULTIPLY, 0, m, &cBinop_xEPyIa8F_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2HDkYwCr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CSbmZQV3_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_qvGLJlfv, 0, m, &sTabread_qvGLJlfv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KOTlYnLU_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_VnNfy3Ma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mIttT3ys, HV_BINOP_SUBTRACT, 1, m, &cBinop_mIttT3ys_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ICfK9pAR, 2, m, &cDelay_ICfK9pAR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MwkPwpho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VnNfy3Ma_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CSbmZQV3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_CDLF9W4D, 0, m, &cDelay_CDLF9W4D_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ICfK9pAR, 0, m, &cDelay_ICfK9pAR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QwrrTqbt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_v4voNlRW, HV_BINOP_MAX, 1, m, &cBinop_v4voNlRW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_v4voNlRW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2HDkYwCr, HV_BINOP_SUBTRACT, 1, m, &cBinop_2HDkYwCr_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KOTlYnLU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CDLF9W4D, 0, m, &cDelay_CDLF9W4D_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_njZx56B3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CDLF9W4D, 2, m, &cDelay_CDLF9W4D_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mIttT3ys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_njZx56B3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sWR5VXXV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1t0kq9gj, 0, m, &cVar_1t0kq9gj_sendMessage);
  cMsg_ZSCsaUV6_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_qNTM3jpW, 0, m, &cTabhead_qNTM3jpW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CzA5aNcD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Z3jkDBZ1, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_xALGukmt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mAsrNk8o, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_diLtVqpP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IxAyg3cQ, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Wi3IpRcZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pKiTGsMO, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_eZyJ2kYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_egE49uz6, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_gGqXlW37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9J54lYWS, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_jksysf7y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IEHxJXbg, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_4Aq3y9IE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1kP4rgcD, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_j9K5rUaY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Ce6Jw9Hr, 0, m, &cSlice_Ce6Jw9Hr_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_Ce6Jw9Hr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_m4SXcNBX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_m4SXcNBX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_KcVLL99y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_m4SXcNBX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_m4SXcNBX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QsXtVNzS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_DYtjFI76_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_wM6sL3Yv, 0, m, &cSlice_wM6sL3Yv_sendMessage);
      break;
    }
    default: {
      cSwitchcase_7lJTNm81_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_wM6sL3Yv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_VIYhgLBU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_VIYhgLBU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_KOCYpNNc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VIYhgLBU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_VIYhgLBU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fU0nJisv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_2ssZVpac_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qqGYDQR5, 0, m, &cSlice_qqGYDQR5_sendMessage);
      break;
    }
    default: {
      cSwitchcase_j9K5rUaY_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_qqGYDQR5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_3ZR2xByl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_3ZR2xByl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_twrwoVBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3ZR2xByl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_3ZR2xByl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YtBpbUiv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_v4tgZFaa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_NuJpA0LA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NuJpA0LA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_mczlN4kP_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_WlSSzxzy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tZW6ilPE_sendMessage(_c, 0, m);
  cMsg_TETVUP3Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_aze04u5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7cMjK4mA_sendMessage(_c, 0, m);
  cMsg_ZwBUKiJk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_mczlN4kP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_zsPBW3yB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zsPBW3yB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9mgQqodi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yLe6oHNF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yLe6oHNF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vEmrS2PQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_9mgQqodi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_NOF2O2nf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NOF2O2nf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_qAqsoIW7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vEmrS2PQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_7K8qGshd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7K8qGshd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_OYydQ9Pl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qAqsoIW7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_WlSSzxzy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OYydQ9Pl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_aze04u5r_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FqDTX5Aq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_59YjSc5Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_59YjSc5Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_R1E6zv6t_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_R1E6zv6t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_H5DSzgWF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_H5DSzgWF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Cf5TGhAH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vaNDP73O_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Cf5TGhAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_3cUrED4I_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vaNDP73O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_45NoBoac_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_3cUrED4I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_nKREwo1M_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_45NoBoac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_OzQtNEMG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OzQtNEMG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_BBHaqG4W_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BBHaqG4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3GYFFN1g_sendMessage(_c, 0, m);
  cMsg_Dp062i4S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_nKREwo1M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RKCX4VuE_sendMessage(_c, 0, m);
  cMsg_nJTqTvE5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_5NSFxAXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_OuEXSzuQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OuEXSzuQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_5WL5dTxL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_GUwxYnQF_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_NGf4sACI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_ePfUgcpk_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XnxXfaFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hcPxPAF7_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_hcPxPAF7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K4eo2Igf, HV_BINOP_DIVIDE, 1, m, &cBinop_K4eo2Igf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5WL5dTxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ono4kfJv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ono4kfJv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_U8n5Zwo5, m);
}

void Heavy_WSTD_DL3Y::cMsg_GPOHwhZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_vXvmcCZb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vXvmcCZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_5NSFxAXP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GUwxYnQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_bk20T1U6, m);
}

void Heavy_WSTD_DL3Y::cBinop_ePfUgcpk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_peE23GPv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_peE23GPv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K4eo2Igf, HV_BINOP_DIVIDE, 0, m, &cBinop_K4eo2Igf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_K4eo2Igf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GPOHwhZH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_jMLCBNTS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_tzi1tWak_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tzi1tWak_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9FKShs6O_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_NNtx7sS0_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_JZUyP15e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_AS6SGZPa_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dlWvRLX5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_mddFPMKU_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_mddFPMKU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_S2vaXTTC, HV_BINOP_DIVIDE, 1, m, &cBinop_S2vaXTTC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9FKShs6O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_RK1z8qr7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RK1z8qr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_AsFhoWNn, m);
}

void Heavy_WSTD_DL3Y::cMsg_NtZ8SfNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_QGYkc15q_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QGYkc15q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_jMLCBNTS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NNtx7sS0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_5xDC1acT, m);
}

void Heavy_WSTD_DL3Y::cBinop_AS6SGZPa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_dD2jFqFd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dD2jFqFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_S2vaXTTC, HV_BINOP_DIVIDE, 0, m, &cBinop_S2vaXTTC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_S2vaXTTC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NtZ8SfNI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_7HoPe3eF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CC6iPg5R, HV_BINOP_MULTIPLY, 0, m, &cBinop_CC6iPg5R_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cczg3qA2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lNSlC4t1_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_lNSlC4t1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iv3mBaTF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_CC6iPg5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_0Ra56aOW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_olvUoqJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CC6iPg5R, HV_BINOP_MULTIPLY, 1, m, &cBinop_CC6iPg5R_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_iv3mBaTF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_olvUoqJh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0Ra56aOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Q0diEnwc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Q0diEnwc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_e9kftsko_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Yb5oFF0V, m);
}

void Heavy_WSTD_DL3Y::cBinop_e9kftsko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_VrsB78nb, m);
}

void Heavy_WSTD_DL3Y::cVar_oSLhhQCu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dxv0UED2, HV_BINOP_MULTIPLY, 0, m, &cBinop_dxv0UED2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1wLe47KV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Dbr1dGGJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Dbr1dGGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1YbIZsjj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_dxv0UED2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_SVSYnAgU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PzFnnt0I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dxv0UED2, HV_BINOP_MULTIPLY, 1, m, &cBinop_dxv0UED2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1YbIZsjj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_PzFnnt0I_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SVSYnAgU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_4EGqs6AQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4EGqs6AQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_hzcSH6k8_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_SGCurf8n, m);
}

void Heavy_WSTD_DL3Y::cBinop_hzcSH6k8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_iLZtWhFM, m);
}

void Heavy_WSTD_DL3Y::sEnv_npDA7nk6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fQKo8JYQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JIEhGf3k_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_LeBfrBep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_R9VPkKSp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_BQc0OAxh_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_wADolb7o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_FG7EGbe5, HV_BINOP_POW, 0, m, &cBinop_FG7EGbe5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FG7EGbe5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lUu16xzc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_exeUfIRy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_STJeQHSi_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fQKo8JYQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_jXBtEZwo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_JIEhGf3k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LeBfrBep, 0, m, &cIf_LeBfrBep_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jXBtEZwo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LeBfrBep, 1, m, &cIf_LeBfrBep_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BQc0OAxh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_exeUfIRy_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_R9VPkKSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_lUu16xzc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_STJeQHSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FG7EGbe5, HV_BINOP_POW, 1, m, &cBinop_FG7EGbe5_sendMessage);
  cMsg_wADolb7o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_ntq0mLW8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E8HpofXe, HV_BINOP_MULTIPLY, 0, m, &cBinop_E8HpofXe_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rPmTdWsY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_iD4L4ARh_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_iD4L4ARh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MCCUMnhA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_E8HpofXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_JbDe9FGj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yK96QW06_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E8HpofXe, HV_BINOP_MULTIPLY, 1, m, &cBinop_E8HpofXe_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MCCUMnhA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_yK96QW06_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JbDe9FGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_BRemLruK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BRemLruK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_1lVQYVrJ_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_uYPmLM6c, m);
}

void Heavy_WSTD_DL3Y::cBinop_1lVQYVrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_aI3jOREu, m);
}

void Heavy_WSTD_DL3Y::cMsg_lUu16xzc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_NRDWHEgl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NRDWHEgl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_AsLYJncj, m);
}

void Heavy_WSTD_DL3Y::sEnv_AFkwDwwx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_28HMioCM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yHGHGA00_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_Zw9qOZiR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_G3Cyf9Bm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_1DjvHTJJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_T6lE3DCj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YIUXnUgF, HV_BINOP_POW, 0, m, &cBinop_YIUXnUgF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YIUXnUgF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GWvDj6qW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_WT7RXuy5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_yX9vsgAO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yHGHGA00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Zw9qOZiR, 0, m, &cIf_Zw9qOZiR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_28HMioCM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Hzs7E2Je_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Hzs7E2Je_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Zw9qOZiR, 1, m, &cIf_Zw9qOZiR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1DjvHTJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_WT7RXuy5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_G3Cyf9Bm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_GWvDj6qW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_yX9vsgAO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YIUXnUgF, HV_BINOP_POW, 1, m, &cBinop_YIUXnUgF_sendMessage);
  cMsg_T6lE3DCj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_RJIwwFYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ktNx9fMX, HV_BINOP_MULTIPLY, 0, m, &cBinop_ktNx9fMX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_j5LNE8kD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pgM587xl_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_pgM587xl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ozuyzk1B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ktNx9fMX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_EdMwqiCA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MHGZH0Sq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ktNx9fMX, HV_BINOP_MULTIPLY, 1, m, &cBinop_ktNx9fMX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Ozuyzk1B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_MHGZH0Sq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EdMwqiCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_TwQIJSjD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TwQIJSjD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_OMWF1IWE_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_UFSFwlvR, m);
}

void Heavy_WSTD_DL3Y::cBinop_OMWF1IWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_LDno1WxL, m);
}

void Heavy_WSTD_DL3Y::cMsg_GWvDj6qW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_SZQywejc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SZQywejc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_L0m9w3fL, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_7lJTNm81_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3u0jjEYP, 0, m, &cSlice_3u0jjEYP_sendMessage);
      break;
    }
    default: {
      cSwitchcase_2ssZVpac_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_3u0jjEYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_V88HXyHu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_V88HXyHu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_NLdwqvYZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_V88HXyHu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_V88HXyHu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_H8N4ZzCi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_JeZdMDLI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ktkrpI9Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ktkrpI9Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_a9cZNfBM_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_Ojz5TOIC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Ojz5TOIC, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_SFHfijQe, 0, m, &cDelay_SFHfijQe_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ojz5TOIC, 0, m, &cDelay_Ojz5TOIC_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_k6EX2Ec1, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_SFHfijQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SFHfijQe, m);
  cMsg_xoesSurh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_32SMwRXC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_i7ngFTME_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_bqiRlzJb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cBpNJB8T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_0TAHHwZp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3xTtP0LK_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ojz5TOIC, 2, m, &cDelay_Ojz5TOIC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KMQcC0jD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cBpNJB8T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_0TAHHwZp, 0, m, &hTable_0TAHHwZp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_a9cZNfBM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_bqiRlzJb_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xoesSurh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_0TAHHwZp, 0, m, &hTable_0TAHHwZp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KMQcC0jD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ojz5TOIC, 0, m, &cDelay_Ojz5TOIC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3xTtP0LK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_SFHfijQe, 2, m, &cDelay_SFHfijQe_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_i7ngFTME_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_k6EX2Ec1, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_0X7J4I9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8kzgLYNM, HV_BINOP_SUBTRACT, 0, m, &cBinop_8kzgLYNM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ABB6w7TE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vWS5CS8a_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_vWS5CS8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_p8IYxsK8_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_MQ2AKT9H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DOLAWKPv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_mfO9sgcF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mfO9sgcF, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hmUkKOOs, 0, m, &cDelay_hmUkKOOs_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_AyNIbarD, 0, m, &sTabread_AyNIbarD_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_hmUkKOOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hmUkKOOs, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_AyNIbarD, 0, m, &sTabread_AyNIbarD_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hmUkKOOs, 0, m, &cDelay_hmUkKOOs_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_AyNIbarD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_GJeSToI8, HV_BINOP_SUBTRACT, 0, m, &cBinop_GJeSToI8_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_GARuUu9p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RQaDRINF, HV_BINOP_MAX, 0, m, &cBinop_RQaDRINF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_p8IYxsK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GARuUu9p, HV_BINOP_MULTIPLY, 0, m, &cBinop_GARuUu9p_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8kzgLYNM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C72PTMxc_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_AyNIbarD, 0, m, &sTabread_AyNIbarD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CE1SLpc9_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Olo91Y2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GJeSToI8, HV_BINOP_SUBTRACT, 1, m, &cBinop_GJeSToI8_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hmUkKOOs, 2, m, &cDelay_hmUkKOOs_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DOLAWKPv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Olo91Y2S_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_C72PTMxc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_mfO9sgcF, 0, m, &cDelay_mfO9sgcF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hmUkKOOs, 0, m, &cDelay_hmUkKOOs_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lhEA0vVw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_RQaDRINF, HV_BINOP_MAX, 1, m, &cBinop_RQaDRINF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RQaDRINF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8kzgLYNM, HV_BINOP_SUBTRACT, 1, m, &cBinop_8kzgLYNM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CE1SLpc9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mfO9sgcF, 0, m, &cDelay_mfO9sgcF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wVsOfMPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mfO9sgcF, 2, m, &cDelay_mfO9sgcF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GJeSToI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_wVsOfMPX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4bCBqSx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MQ2AKT9H, 0, m, &cVar_MQ2AKT9H_sendMessage);
  cMsg_ABB6w7TE_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_0X7J4I9b, 0, m, &cTabhead_0X7J4I9b_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hGQpA73H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JkdxNhKS_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_JkdxNhKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_L84sa8dj_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_qLQAzfpJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qLQAzfpJ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vYJtdHUL, 0, m, &cDelay_vYJtdHUL_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qLQAzfpJ, 0, m, &cDelay_qLQAzfpJ_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_7AZkZ8k8, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_vYJtdHUL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vYJtdHUL, m);
  cMsg_6uTziqGP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_8yhEDjuq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_QxBa9IhT_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_vk9TQydM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1L38Zfcp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_2slfKaAf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TVRoztHm_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qLQAzfpJ, 2, m, &cDelay_qLQAzfpJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PKWjIDA2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1L38Zfcp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_2slfKaAf, 0, m, &hTable_2slfKaAf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_L84sa8dj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_vk9TQydM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6uTziqGP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_2slfKaAf, 0, m, &hTable_2slfKaAf_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_PKWjIDA2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_qLQAzfpJ, 0, m, &cDelay_qLQAzfpJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TVRoztHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_vYJtdHUL, 2, m, &cDelay_vYJtdHUL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QxBa9IhT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_7AZkZ8k8, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_mT1FtaSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3fANrXCg, HV_BINOP_SUBTRACT, 0, m, &cBinop_3fANrXCg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_G8Zpgsi9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KITjqw9S_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_KITjqw9S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_aIzHJJ8Q_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_eClkqDOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QY5elfoC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_3msIjfdC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3msIjfdC, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Vws1PZGg, 0, m, &cDelay_Vws1PZGg_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_hauLLylu, 0, m, &sTabread_hauLLylu_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_Vws1PZGg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Vws1PZGg, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_hauLLylu, 0, m, &sTabread_hauLLylu_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Vws1PZGg, 0, m, &cDelay_Vws1PZGg_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_hauLLylu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_hIUElCy1, HV_BINOP_SUBTRACT, 0, m, &cBinop_hIUElCy1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_yYzzHPYh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dQQDwB2z, HV_BINOP_MAX, 0, m, &cBinop_dQQDwB2z_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aIzHJJ8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yYzzHPYh, HV_BINOP_MULTIPLY, 0, m, &cBinop_yYzzHPYh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3fANrXCg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UAZGSwoV_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_hauLLylu, 0, m, &sTabread_hauLLylu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4fVEO50d_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_5jG5m9e3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hIUElCy1, HV_BINOP_SUBTRACT, 1, m, &cBinop_hIUElCy1_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Vws1PZGg, 2, m, &cDelay_Vws1PZGg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QY5elfoC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_5jG5m9e3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UAZGSwoV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_3msIjfdC, 0, m, &cDelay_3msIjfdC_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Vws1PZGg, 0, m, &cDelay_Vws1PZGg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_osLcp4O6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_dQQDwB2z, HV_BINOP_MAX, 1, m, &cBinop_dQQDwB2z_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dQQDwB2z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3fANrXCg, HV_BINOP_SUBTRACT, 1, m, &cBinop_3fANrXCg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4fVEO50d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3msIjfdC, 0, m, &cDelay_3msIjfdC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_04o3Hp3K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3msIjfdC, 2, m, &cDelay_3msIjfdC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hIUElCy1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_04o3Hp3K_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Hesjxc3E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eClkqDOl, 0, m, &cVar_eClkqDOl_sendMessage);
  cMsg_G8Zpgsi9_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_mT1FtaSr, 0, m, &cTabhead_mT1FtaSr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tZW6ilPE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EVon1jSf, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_7cMjK4mA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wEoA3xCZ, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ZwBUKiJk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OMQsBF0A, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_TETVUP3Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tCIdo3OO, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_nJTqTvE5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nAl6Eubo, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_3GYFFN1g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1eD5HXG7, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_RKCX4VuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vX2wY3s1, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Dp062i4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LGOOWNep, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_gOig2Vzt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_JOLHuevH, 0, m, &cSlice_JOLHuevH_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_JOLHuevH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_6kZjCeby_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_6kZjCeby_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_tf6Mdqsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6kZjCeby_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_6kZjCeby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hTplozxz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_4ueZVNSh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PqYbBZhS, 0, m, &cSlice_PqYbBZhS_sendMessage);
      break;
    }
    default: {
      cSwitchcase_9wD2ANaz_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_PqYbBZhS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ZFx0Qmc0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ZFx0Qmc0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_UpkDqmkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZFx0Qmc0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_ZFx0Qmc0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OQgR9ls7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_bElLlrQ8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CW6IzQKn, 0, m, &cSlice_CW6IzQKn_sendMessage);
      break;
    }
    default: {
      cSwitchcase_gOig2Vzt_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_CW6IzQKn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_SAA0R5UY_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_SAA0R5UY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_5PP4lbpI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SAA0R5UY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_SAA0R5UY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_I7S7dz8Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_zaY5PYBS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_NYXqLxy4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NYXqLxy4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_79gF0xmn_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_rPzX2X3b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BDZKoVEu_sendMessage(_c, 0, m);
  cMsg_t6yoovIp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_JTg7BqVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_whWLlSWW_sendMessage(_c, 0, m);
  cMsg_30djolIH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_79gF0xmn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_0XZaCCWD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0XZaCCWD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_alD7rOcK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DgnXUhKq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DgnXUhKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7vSwl36U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_alD7rOcK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_lVcyIo9w_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lVcyIo9w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_HBofBCxg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7vSwl36U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_YMf2CdN4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YMf2CdN4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_peYjaPyz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HBofBCxg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_rPzX2X3b_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_peYjaPyz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_JTg7BqVq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_daEjz6zh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_hdCG7VaT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hdCG7VaT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_cmkedFD5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cmkedFD5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_BsSoVbit_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BsSoVbit_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_boGzG3H8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UamUJsVz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_UamUJsVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V3NQGTF2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_boGzG3H8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_VQSlpBJV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VQSlpBJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Q55xmk7d_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_V3NQGTF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_O6TeXago_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_O6TeXago_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Z3BNdciY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Z3BNdciY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZKh0B6cv_sendMessage(_c, 0, m);
  cMsg_oyKkpue5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Q55xmk7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P4618UYS_sendMessage(_c, 0, m);
  cMsg_SzmSFg3y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_qhpkyadH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_gQkTWJHB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gQkTWJHB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_NdfR1UZq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_aT7v29y9_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_JpEMlwb1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_gZDFm982_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XmhRH36s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XcQCDhRq_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_XcQCDhRq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PPd7ayJa, HV_BINOP_DIVIDE, 1, m, &cBinop_PPd7ayJa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NdfR1UZq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_XXVgiyzq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XXVgiyzq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_RnPQOUXa, m);
}

void Heavy_WSTD_DL3Y::cMsg_am7NJBhh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_BUrrA9B4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BUrrA9B4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_qhpkyadH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aT7v29y9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_cCFfodNy, m);
}

void Heavy_WSTD_DL3Y::cBinop_gZDFm982_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_RqED4aOl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RqED4aOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PPd7ayJa, HV_BINOP_DIVIDE, 0, m, &cBinop_PPd7ayJa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PPd7ayJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_am7NJBhh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_MoR2tpXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_z5ooN3xq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_z5ooN3xq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_DBM4MKjO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_JTUkcQXA_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_6KlGhQZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_R7hPPLh2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZpHUlfLI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_4FMNeQu9_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_4FMNeQu9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fDiaVjPt, HV_BINOP_DIVIDE, 1, m, &cBinop_fDiaVjPt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DBM4MKjO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_2savchBZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2savchBZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_G73wGL4l, m);
}

void Heavy_WSTD_DL3Y::cMsg_0IRO9Dk4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_kMPpX4Y5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kMPpX4Y5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_MoR2tpXd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JTUkcQXA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_OQUjnLcN, m);
}

void Heavy_WSTD_DL3Y::cBinop_R7hPPLh2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_ZeNZoJHa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZeNZoJHa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fDiaVjPt, HV_BINOP_DIVIDE, 0, m, &cBinop_fDiaVjPt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fDiaVjPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0IRO9Dk4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_FGIjolnh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OUib0Mqx, HV_BINOP_MULTIPLY, 0, m, &cBinop_OUib0Mqx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hJr2oX8A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Mts32v6z_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Mts32v6z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8UpKUQGc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_OUib0Mqx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_MvXDcO0v_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Se5Sl1ra_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OUib0Mqx, HV_BINOP_MULTIPLY, 1, m, &cBinop_OUib0Mqx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8UpKUQGc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Se5Sl1ra_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MvXDcO0v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_5y65KTmR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5y65KTmR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_LSXTMYW0_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_rDlQJ2It, m);
}

void Heavy_WSTD_DL3Y::cBinop_LSXTMYW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_I1VDkNm9, m);
}

void Heavy_WSTD_DL3Y::cVar_JMqrIxpG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tb1LDzaZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_tb1LDzaZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NWjPGLmw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MtBJgiNc_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_MtBJgiNc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BoHAxGVo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_tb1LDzaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_meQqTQgm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oxWsZFTP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tb1LDzaZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_tb1LDzaZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BoHAxGVo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_oxWsZFTP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_meQqTQgm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_JR6QYpIB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JR6QYpIB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_xi2rcAey_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_21BZj11C, m);
}

void Heavy_WSTD_DL3Y::cBinop_xi2rcAey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ABBx7l3m, m);
}

void Heavy_WSTD_DL3Y::sEnv_OYV90pPc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wUZcAnNU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OCn5Axc3_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_B0kGWEIZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_mLEBWbjc_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_7nMA2AMv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_kMqso0tK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9TOIeV5y, HV_BINOP_POW, 0, m, &cBinop_9TOIeV5y_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9TOIeV5y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sH1s2gCc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_5nLMkyrj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_83yB0NCk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_OCn5Axc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_B0kGWEIZ, 0, m, &cIf_B0kGWEIZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wUZcAnNU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ZxIgJXzO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZxIgJXzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_B0kGWEIZ, 1, m, &cIf_B0kGWEIZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7nMA2AMv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_5nLMkyrj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mLEBWbjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_sH1s2gCc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_83yB0NCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9TOIeV5y, HV_BINOP_POW, 1, m, &cBinop_9TOIeV5y_sendMessage);
  cMsg_kMqso0tK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_QPRAVli1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A1OyVFqj, HV_BINOP_MULTIPLY, 0, m, &cBinop_A1OyVFqj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CCssk4IR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8XpvhpLC_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_8XpvhpLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8KTCMjSU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_A1OyVFqj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_d3bGkXcT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MIoEDHbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A1OyVFqj, HV_BINOP_MULTIPLY, 1, m, &cBinop_A1OyVFqj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8KTCMjSU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_MIoEDHbx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_d3bGkXcT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_fEuAGEUq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fEuAGEUq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_IytfeETC_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_BApyv1Gq, m);
}

void Heavy_WSTD_DL3Y::cBinop_IytfeETC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_EmUKfeuo, m);
}

void Heavy_WSTD_DL3Y::cMsg_sH1s2gCc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_12IXaqL2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_12IXaqL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_4B923pwn, m);
}

void Heavy_WSTD_DL3Y::sEnv_teB4zooV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WEnHPqjE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aSRV6x0s_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_zUVbX7gt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_ViRTBE1b_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_YqCBc9Xf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_FzcMMaLR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_FTGPWBEj, HV_BINOP_POW, 0, m, &cBinop_FTGPWBEj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FTGPWBEj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WFFKaCKp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_D5yzHHCV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_6HyoSHri_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_aSRV6x0s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zUVbX7gt, 0, m, &cIf_zUVbX7gt_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_WEnHPqjE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_SPI7pe4l_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SPI7pe4l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zUVbX7gt, 1, m, &cIf_zUVbX7gt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YqCBc9Xf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_D5yzHHCV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ViRTBE1b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_WFFKaCKp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_6HyoSHri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FTGPWBEj, HV_BINOP_POW, 1, m, &cBinop_FTGPWBEj_sendMessage);
  cMsg_FzcMMaLR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_P5XMJ71r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1ZsiYOk6, HV_BINOP_MULTIPLY, 0, m, &cBinop_1ZsiYOk6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_F3Cjl6W5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9WlRwp3j_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_9WlRwp3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HuNFHKgt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_1ZsiYOk6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_WgMsgF00_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2XGC67ki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1ZsiYOk6, HV_BINOP_MULTIPLY, 1, m, &cBinop_1ZsiYOk6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_HuNFHKgt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_2XGC67ki_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WgMsgF00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_SQAyxqij_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SQAyxqij_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_3XUiLxNT_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_yYc0wpvi, m);
}

void Heavy_WSTD_DL3Y::cBinop_3XUiLxNT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_DaCUl07F, m);
}

void Heavy_WSTD_DL3Y::cMsg_WFFKaCKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_xbgEi1Z2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xbgEi1Z2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_RJWhLfGq, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_9wD2ANaz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_nAAhBA8j, 0, m, &cSlice_nAAhBA8j_sendMessage);
      break;
    }
    default: {
      cSwitchcase_bElLlrQ8_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_nAAhBA8j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9SPq10Gx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9SPq10Gx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_OEqys86i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9SPq10Gx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_9SPq10Gx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GpVZMMNT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_YdFA5qeN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RjH2mcZI_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_RjH2mcZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_DFoDeD0l_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_4RzxTjWH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4RzxTjWH, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oiRruCSi, 0, m, &cDelay_oiRruCSi_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_4RzxTjWH, 0, m, &cDelay_4RzxTjWH_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_gGztJXJA, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_oiRruCSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oiRruCSi, m);
  cMsg_3WoPuGi8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_BKRacaMz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_nqK4zCzQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_zSRNLFF8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iOtQIMHa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_tsPDcfOd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kNu3Lou0_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_4RzxTjWH, 2, m, &cDelay_4RzxTjWH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mvzoqky0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_iOtQIMHa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_tsPDcfOd, 0, m, &hTable_tsPDcfOd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DFoDeD0l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_zSRNLFF8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3WoPuGi8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_tsPDcfOd, 0, m, &hTable_tsPDcfOd_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_mvzoqky0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4RzxTjWH, 0, m, &cDelay_4RzxTjWH_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kNu3Lou0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_oiRruCSi, 2, m, &cDelay_oiRruCSi_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nqK4zCzQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_gGztJXJA, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_ij6xZJJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dl1bHG6K, HV_BINOP_SUBTRACT, 0, m, &cBinop_dl1bHG6K_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MaJ0gCgV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zt2rWOnD_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_zt2rWOnD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_gYMILecu_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_HqC4WwzQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Rw0rIWFx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_Py5E7JBY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Py5E7JBY, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OTLpC7NJ, 0, m, &cDelay_OTLpC7NJ_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_OhtVlxcf, 0, m, &sTabread_OhtVlxcf_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_OTLpC7NJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OTLpC7NJ, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_OhtVlxcf, 0, m, &sTabread_OhtVlxcf_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OTLpC7NJ, 0, m, &cDelay_OTLpC7NJ_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_OhtVlxcf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_0C8VKAmM, HV_BINOP_SUBTRACT, 0, m, &cBinop_0C8VKAmM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_apxm0LdI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6ooDNKSQ, HV_BINOP_MAX, 0, m, &cBinop_6ooDNKSQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gYMILecu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_apxm0LdI, HV_BINOP_MULTIPLY, 0, m, &cBinop_apxm0LdI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dl1bHG6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fBcPOkje_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_OhtVlxcf, 0, m, &sTabread_OhtVlxcf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hhKHYcuf_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_kg9uxTmN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0C8VKAmM, HV_BINOP_SUBTRACT, 1, m, &cBinop_0C8VKAmM_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OTLpC7NJ, 2, m, &cDelay_OTLpC7NJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Rw0rIWFx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kg9uxTmN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_fBcPOkje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Py5E7JBY, 0, m, &cDelay_Py5E7JBY_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OTLpC7NJ, 0, m, &cDelay_OTLpC7NJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Z73hfvJc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_6ooDNKSQ, HV_BINOP_MAX, 1, m, &cBinop_6ooDNKSQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6ooDNKSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dl1bHG6K, HV_BINOP_SUBTRACT, 1, m, &cBinop_dl1bHG6K_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hhKHYcuf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Py5E7JBY, 0, m, &cDelay_Py5E7JBY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LO8Jz7Oh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Py5E7JBY, 2, m, &cDelay_Py5E7JBY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0C8VKAmM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_LO8Jz7Oh_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_n1BRn1Pf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HqC4WwzQ, 0, m, &cVar_HqC4WwzQ_sendMessage);
  cMsg_MaJ0gCgV_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_ij6xZJJZ, 0, m, &cTabhead_ij6xZJJZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3gtSACcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_X5KGOocY_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_X5KGOocY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Vc4Me4aO_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_LyZl5Kfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LyZl5Kfs, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Kfpjj1sT, 0, m, &cDelay_Kfpjj1sT_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LyZl5Kfs, 0, m, &cDelay_LyZl5Kfs_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_YiOIMMZD, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_Kfpjj1sT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Kfpjj1sT, m);
  cMsg_X3zk1LKF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_BiaFzAq9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_v0vWeiR5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_XfajdO9q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b5DyH6ab_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_6gHb7SX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Sqimb8Fk_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LyZl5Kfs, 2, m, &cDelay_LyZl5Kfs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xaSiS1CG_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_b5DyH6ab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_6gHb7SX0, 0, m, &hTable_6gHb7SX0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Vc4Me4aO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_XfajdO9q_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_X3zk1LKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_6gHb7SX0, 0, m, &hTable_6gHb7SX0_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xaSiS1CG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_LyZl5Kfs, 0, m, &cDelay_LyZl5Kfs_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Sqimb8Fk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Kfpjj1sT, 2, m, &cDelay_Kfpjj1sT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_v0vWeiR5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_YiOIMMZD, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_MMf7dAwu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZHXjWMfX, HV_BINOP_SUBTRACT, 0, m, &cBinop_ZHXjWMfX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_o5hDE6vn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_boJVVLpX_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_boJVVLpX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_yQlJPCrk_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_oLo6Abwe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DAH2Nw8f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_Cgw1edCG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Cgw1edCG, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FK0SRWxZ, 0, m, &cDelay_FK0SRWxZ_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_X2EEAVfE, 0, m, &sTabread_X2EEAVfE_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_FK0SRWxZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FK0SRWxZ, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_X2EEAVfE, 0, m, &sTabread_X2EEAVfE_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FK0SRWxZ, 0, m, &cDelay_FK0SRWxZ_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_X2EEAVfE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_kpzsJyUM, HV_BINOP_SUBTRACT, 0, m, &cBinop_kpzsJyUM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_SEki2U0h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eY6XBFbk, HV_BINOP_MAX, 0, m, &cBinop_eY6XBFbk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yQlJPCrk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SEki2U0h, HV_BINOP_MULTIPLY, 0, m, &cBinop_SEki2U0h_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZHXjWMfX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Qcoq9x8b_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_X2EEAVfE, 0, m, &sTabread_X2EEAVfE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Iu7Sbpc0_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_cjm6i6et_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kpzsJyUM, HV_BINOP_SUBTRACT, 1, m, &cBinop_kpzsJyUM_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FK0SRWxZ, 2, m, &cDelay_FK0SRWxZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DAH2Nw8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cjm6i6et_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Qcoq9x8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cgw1edCG, 0, m, &cDelay_Cgw1edCG_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FK0SRWxZ, 0, m, &cDelay_FK0SRWxZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZAUopW4Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_eY6XBFbk, HV_BINOP_MAX, 1, m, &cBinop_eY6XBFbk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eY6XBFbk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZHXjWMfX, HV_BINOP_SUBTRACT, 1, m, &cBinop_ZHXjWMfX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Iu7Sbpc0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cgw1edCG, 0, m, &cDelay_Cgw1edCG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yp09eYJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cgw1edCG, 2, m, &cDelay_Cgw1edCG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kpzsJyUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_yp09eYJq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vUDicrE4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oLo6Abwe, 0, m, &cVar_oLo6Abwe_sendMessage);
  cMsg_o5hDE6vn_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_MMf7dAwu, 0, m, &cTabhead_MMf7dAwu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BDZKoVEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QpnaNcY1, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_whWLlSWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PdXXWjW3, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_30djolIH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WGF5eXzV, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_t6yoovIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Sz1FCUmg, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_SzmSFg3y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_W0LaHzsa, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ZKh0B6cv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RiiDhfRN, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_P4618UYS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_B8XC1E0x, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_oyKkpue5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8J98VVQg, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cVar_nRZyyCus_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DNmA3faA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eTtoJF0R_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_fpbVsOd3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DNmA3faA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nRZyyCus, 1, m, &cVar_nRZyyCus_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_GUT3AUAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_FnTzIX64, 0, m, &cVar_FnTzIX64_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_uCnfokaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_FnTzIX64, 0, m, &cVar_FnTzIX64_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_9aJY6LP6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uCnfokaZ, 0, m, &cIf_uCnfokaZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_PYTtcpMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GUT3AUAS, 0, m, &cIf_GUT3AUAS_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_d6DUnOim_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xoS0EXw6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_f0bCMor7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_1LxTZXzS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xoS0EXw6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_d6DUnOim, 1, m, &cVar_d6DUnOim_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_s7UcZAU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_31jiv2pb, 0, m, &cVar_31jiv2pb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_VZsmjUkK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_31jiv2pb, 0, m, &cVar_31jiv2pb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_OtGhFBXU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VZsmjUkK, 0, m, &cIf_VZsmjUkK_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_mlD6JQhQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_s7UcZAU1, 0, m, &cIf_s7UcZAU1_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_FkEyWuef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8lhfCAoX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8MeNqaCe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Zp0tHKm5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8lhfCAoX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FkEyWuef, 1, m, &cVar_FkEyWuef_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_IahScxMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_9KO4oCea, 0, m, &cVar_9KO4oCea_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_Uqs9PG6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_9KO4oCea, 0, m, &cVar_9KO4oCea_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_1KaVOf5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Uqs9PG6N, 0, m, &cIf_Uqs9PG6N_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_udjtFJzH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IahScxMj, 0, m, &cIf_IahScxMj_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_WKkeeLwL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ncPVQZb8, HV_BINOP_DIVIDE, 0, m, &cBinop_ncPVQZb8_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_XaH6AMUS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8xyWI8e8, HV_BINOP_MULTIPLY, 1, m, &cBinop_8xyWI8e8_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_xtTSGVBO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_X8AzfFFY, 0, m, &cSlice_X8AzfFFY_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DAI0zMGu, 0, m, &cSlice_DAI0zMGu_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jmanbOaF_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_p5yxvRy2_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_X8AzfFFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_9h2OcE6u, 0, m, &cVar_9h2OcE6u_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_9h2OcE6u, 0, m, &cVar_9h2OcE6u_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_DAI0zMGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_te16GYzz, HV_BINOP_NEQ, 1, m, &cBinop_te16GYzz_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_9h2OcE6u, 1, m, &cVar_9h2OcE6u_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_te16GYzz, HV_BINOP_NEQ, 1, m, &cBinop_te16GYzz_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_9h2OcE6u, 1, m, &cVar_9h2OcE6u_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_9h2OcE6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_uNn2dpzd_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_o18I9DCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wOmD4rX6_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qU4JiwzS_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_qU4JiwzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9h2OcE6u, 0, m, &cVar_9h2OcE6u_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wOmD4rX6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_te16GYzz, HV_BINOP_NEQ, 1, m, &cBinop_te16GYzz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_te16GYzz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_o18I9DCk, 1, m, &cIf_o18I9DCk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_p5yxvRy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_o18I9DCk, 0, m, &cIf_o18I9DCk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jmanbOaF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_te16GYzz, HV_BINOP_NEQ, 0, m, &cBinop_te16GYzz_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_BHAV7Ycj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WmDXfRLs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EofA5kV0_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_uHNDRm5H_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GN058J0B_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RMPNsDmc_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NzZ0xM3U_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BY5QjJaY_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yQWWX58p_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_91wEuWe9_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f8C9QZUE_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4oJlHqIx_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wn7J0q5W_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RzhLzCWt_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cYZpqaRc_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FoawUQKj_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2QvSJOSU_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_GN058J0B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UHo1vkin_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_RMPNsDmc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eYgiMiQF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_NzZ0xM3U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yekjB1iV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_BY5QjJaY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gObvARNA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_yQWWX58p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sZnuJlaF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_91wEuWe9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aJN8DqAO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_f8C9QZUE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DpfQPRgk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_4oJlHqIx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UepUCIFB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_wn7J0q5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6Pae3ETz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_RzhLzCWt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SsNxEJDx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_cYZpqaRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E7yBoUPD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_FoawUQKj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6g1HsYjK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_2QvSJOSU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Jsl4zfXN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ncPVQZb8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8xyWI8e8, HV_BINOP_MULTIPLY, 0, m, &cBinop_8xyWI8e8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8xyWI8e8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_xtTSGVBO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_WmDXfRLs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ncPVQZb8, HV_BINOP_DIVIDE, 1, m, &cBinop_ncPVQZb8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EofA5kV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WKkeeLwL, 0, m, &cVar_WKkeeLwL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XaH6AMUS, 0, m, &cVar_XaH6AMUS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DD8cMMYZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XaH6AMUS, 0, m, &cVar_XaH6AMUS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_YcvpssF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WKkeeLwL, 0, m, &cVar_WKkeeLwL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UHo1vkin_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DD8cMMYZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YcvpssF3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_eYgiMiQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DD8cMMYZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YcvpssF3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_yekjB1iV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DD8cMMYZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YcvpssF3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gObvARNA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DD8cMMYZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YcvpssF3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_sZnuJlaF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DD8cMMYZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YcvpssF3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_aJN8DqAO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DD8cMMYZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YcvpssF3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DpfQPRgk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DD8cMMYZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YcvpssF3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UepUCIFB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DD8cMMYZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YcvpssF3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6Pae3ETz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DD8cMMYZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YcvpssF3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SsNxEJDx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DD8cMMYZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YcvpssF3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_E7yBoUPD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DD8cMMYZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YcvpssF3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6g1HsYjK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DD8cMMYZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YcvpssF3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Jsl4zfXN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DD8cMMYZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YcvpssF3_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Ic4aCLaa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kqUDvPDg, HV_BINOP_DIVIDE, 0, m, &cBinop_kqUDvPDg_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_MNJyceZf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SdGd6fBH, HV_BINOP_MULTIPLY, 1, m, &cBinop_SdGd6fBH_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_IS9YFoyf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_eb2sY5uw, 0, m, &cSlice_eb2sY5uw_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_JwGjCOQ2, 0, m, &cSlice_JwGjCOQ2_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eM8H2ZNw_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TowPuiqm_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_eb2sY5uw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_ZDaOLlyU, 0, m, &cVar_ZDaOLlyU_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_ZDaOLlyU, 0, m, &cVar_ZDaOLlyU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_JwGjCOQ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_xV8L0IVU, HV_BINOP_NEQ, 1, m, &cBinop_xV8L0IVU_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_ZDaOLlyU, 1, m, &cVar_ZDaOLlyU_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_xV8L0IVU, HV_BINOP_NEQ, 1, m, &cBinop_xV8L0IVU_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_ZDaOLlyU, 1, m, &cVar_ZDaOLlyU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_ZDaOLlyU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_GwOcAxTA_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_2O3Y2VTn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kzghCPJm_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hCu76RdD_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_hCu76RdD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZDaOLlyU, 0, m, &cVar_ZDaOLlyU_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_kzghCPJm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xV8L0IVU, HV_BINOP_NEQ, 1, m, &cBinop_xV8L0IVU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xV8L0IVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2O3Y2VTn, 1, m, &cIf_2O3Y2VTn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TowPuiqm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2O3Y2VTn, 0, m, &cIf_2O3Y2VTn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_eM8H2ZNw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xV8L0IVU, HV_BINOP_NEQ, 0, m, &cBinop_xV8L0IVU_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_JaoQnoqx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E7pv6Qw6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E4FcYPvv_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_1NpiGfE9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6OP36xAT_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lcggwsd1_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IQ35LWHh_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_figsJNl6_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0q8JgDqk_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NmP7CbGD_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sJ8ZrT15_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ADDqCQAN_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j3wGaX1y_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h67u8kV0_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QxxRDQgG_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QGzdBvjY_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CzY3EL5K_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_6OP36xAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cJ9xMFbj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_lcggwsd1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CC031EtP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_IQ35LWHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bVAaEBwR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_figsJNl6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7AYbF9Fz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_0q8JgDqk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QoNWb6Tz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_NmP7CbGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EIzt9G4m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_sJ8ZrT15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QBBfmyfO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ADDqCQAN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cfujQ11Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_j3wGaX1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VsYuD4U2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_h67u8kV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W81arYUO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_QxxRDQgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b2harDOu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_QGzdBvjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Pu3WEfNp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_CzY3EL5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GAevYwqb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_kqUDvPDg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SdGd6fBH, HV_BINOP_MULTIPLY, 0, m, &cBinop_SdGd6fBH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SdGd6fBH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_IS9YFoyf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_E4FcYPvv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ic4aCLaa, 0, m, &cVar_Ic4aCLaa_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MNJyceZf, 0, m, &cVar_MNJyceZf_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_E7pv6Qw6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kqUDvPDg, HV_BINOP_DIVIDE, 1, m, &cBinop_kqUDvPDg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_waMdz9tq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MNJyceZf, 0, m, &cVar_MNJyceZf_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3M75LotX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ic4aCLaa, 0, m, &cVar_Ic4aCLaa_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cJ9xMFbj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_waMdz9tq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3M75LotX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CC031EtP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_waMdz9tq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3M75LotX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bVAaEBwR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_waMdz9tq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3M75LotX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7AYbF9Fz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_waMdz9tq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3M75LotX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QoNWb6Tz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_waMdz9tq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3M75LotX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_EIzt9G4m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_waMdz9tq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3M75LotX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QBBfmyfO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_waMdz9tq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3M75LotX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cfujQ11Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_waMdz9tq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3M75LotX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_VsYuD4U2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_waMdz9tq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3M75LotX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_W81arYUO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_waMdz9tq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3M75LotX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_b2harDOu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_waMdz9tq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3M75LotX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Pu3WEfNp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_waMdz9tq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3M75LotX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_GAevYwqb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_waMdz9tq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3M75LotX_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_cm5GRJhn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7niSd2BZ, HV_BINOP_DIVIDE, 0, m, &cBinop_7niSd2BZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_PAF5ogTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V8YXf1nC, HV_BINOP_MULTIPLY, 1, m, &cBinop_V8YXf1nC_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_bfkivtaw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0UNdDdaB, 0, m, &cSlice_0UNdDdaB_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_MExpArSZ, 0, m, &cSlice_MExpArSZ_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Bg9e72uF_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_A8T4tlFs_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_0UNdDdaB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_ou2sB811, 0, m, &cVar_ou2sB811_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_ou2sB811, 0, m, &cVar_ou2sB811_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_MExpArSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_Y4JLGdX0, HV_BINOP_NEQ, 1, m, &cBinop_Y4JLGdX0_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_ou2sB811, 1, m, &cVar_ou2sB811_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_Y4JLGdX0, HV_BINOP_NEQ, 1, m, &cBinop_Y4JLGdX0_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_ou2sB811, 1, m, &cVar_ou2sB811_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_ou2sB811_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_duWuAGxz_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_rYlrPk7o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VHehOzJZ_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5ToO4Lm6_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_5ToO4Lm6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ou2sB811, 0, m, &cVar_ou2sB811_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_VHehOzJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y4JLGdX0, HV_BINOP_NEQ, 1, m, &cBinop_Y4JLGdX0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Y4JLGdX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rYlrPk7o, 1, m, &cIf_rYlrPk7o_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_A8T4tlFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rYlrPk7o, 0, m, &cIf_rYlrPk7o_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Bg9e72uF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y4JLGdX0, HV_BINOP_NEQ, 0, m, &cBinop_Y4JLGdX0_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_1kQOeo2Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AdVxIOUg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5hVctfM9_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_0Lgqp6Cb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Z1uhVSIh_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KenLRpSU_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T0C89BJB_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RfqA1cZx_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ueresq5v_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_epLmjNSA_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_t1qXACDp_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_59O50dnI_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Dfcr8M0K_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0y4gDn01_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7WzRwQkE_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2aPjRae8_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7U08Ogy3_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_Z1uhVSIh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YnPUUxAx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_KenLRpSU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BZz9kq7G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_T0C89BJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GysEvQUy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_RfqA1cZx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FyqLNYrX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ueresq5v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hDsXNzQY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_epLmjNSA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FYMLLCde_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_t1qXACDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gZ5Vlaue_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_59O50dnI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mzvcVQPq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Dfcr8M0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E96jPCOl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_0y4gDn01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_03l5DMsa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_7WzRwQkE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7n2v8yzM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_2aPjRae8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QPTttVCW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_7U08Ogy3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HuPdiarI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_7niSd2BZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V8YXf1nC, HV_BINOP_MULTIPLY, 0, m, &cBinop_V8YXf1nC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_V8YXf1nC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_bfkivtaw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_5hVctfM9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cm5GRJhn, 0, m, &cVar_cm5GRJhn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PAF5ogTY, 0, m, &cVar_PAF5ogTY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_AdVxIOUg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7niSd2BZ, HV_BINOP_DIVIDE, 1, m, &cBinop_7niSd2BZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZX7PEenq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PAF5ogTY, 0, m, &cVar_PAF5ogTY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_RLGRTAJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cm5GRJhn, 0, m, &cVar_cm5GRJhn_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YnPUUxAx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZX7PEenq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RLGRTAJS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BZz9kq7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZX7PEenq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RLGRTAJS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_GysEvQUy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZX7PEenq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RLGRTAJS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_FyqLNYrX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZX7PEenq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RLGRTAJS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hDsXNzQY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZX7PEenq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RLGRTAJS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_FYMLLCde_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZX7PEenq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RLGRTAJS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gZ5Vlaue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZX7PEenq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RLGRTAJS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mzvcVQPq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZX7PEenq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RLGRTAJS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_E96jPCOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZX7PEenq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RLGRTAJS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_03l5DMsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZX7PEenq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RLGRTAJS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7n2v8yzM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZX7PEenq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RLGRTAJS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QPTttVCW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZX7PEenq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RLGRTAJS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_HuPdiarI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZX7PEenq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RLGRTAJS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tVFx0Qn0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_hqK7WYuV_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_h8mVwoAk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_9GTKAFyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_hqK7WYuV_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_h8mVwoAk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_0Wdran0e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_hqK7WYuV_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_h8mVwoAk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Fcm6zj75_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_hqK7WYuV_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_h8mVwoAk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_7IGJTXdH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_hqK7WYuV_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_h8mVwoAk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_8tveOxt4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_P0SMmeIA, 0, m, &cVar_P0SMmeIA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_81uVh4tr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_dR1uxmMW, 0, m, &cVar_dR1uxmMW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HOgPLNOB, 0, m, &cVar_HOgPLNOB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2V4smvIF, 0, m, &cVar_2V4smvIF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_oQJ6xizy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_QzGbkL4B_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_eKAm7rRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_QzGbkL4B_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_X5ZKbpKM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aS3Gdal4, 0, m, &cVar_aS3Gdal4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eac7whUf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pGbZ12Ub, 0, m, &cVar_pGbZ12Ub_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oSl2oxER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2E47ak7X, 0, m, &cVar_2E47ak7X_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_f0iQ5aaQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_QzGbkL4B_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_aNyOFAZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_QzGbkL4B_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_arbXmFFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DYtjFI76_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_3uUv1Xe6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DYtjFI76_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_iIM5BbuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kIU4E1gb, 0, m, &cVar_kIU4E1gb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_U2hmZwQP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GhbHQAux, 0, m, &cVar_GhbHQAux_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MgAOYnLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ewGwOSBS, 0, m, &cVar_ewGwOSBS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rlOEb2Hm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DYtjFI76_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_iAAlP2pS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DYtjFI76_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_vXkvmzSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4ueZVNSh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_KaIXUeCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4ueZVNSh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_KZnkMZRu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pxPuCY2V, 0, m, &cVar_pxPuCY2V_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_llh3XFtO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FUWa9NDu, 0, m, &cVar_FUWa9NDu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_W0ESkSaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XtqshasM, 0, m, &cVar_XtqshasM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gxl8Glqp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4ueZVNSh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_NWJAphDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4ueZVNSh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_uNn2dpzd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PYTtcpMD, 0, m, &cVar_PYTtcpMD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fpbVsOd3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZCL5Fy4l_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BH0rXALo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eTtoJF0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n0sopMwL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4JQmizCJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_n0sopMwL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uCnfokaZ, 1, m, &cIf_uCnfokaZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4JQmizCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9aJY6LP6, 0, m, &cVar_9aJY6LP6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_BH0rXALo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PYTtcpMD, 0, m, &cVar_PYTtcpMD_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZCL5Fy4l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GUT3AUAS, 1, m, &cIf_GUT3AUAS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GwOcAxTA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mlD6JQhQ, 0, m, &cVar_mlD6JQhQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1LxTZXzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ge9fNW25_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KkbpKawz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_f0bCMor7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cXocXLX5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pK6Q11R2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cXocXLX5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VZsmjUkK, 1, m, &cIf_VZsmjUkK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pK6Q11R2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OtGhFBXU, 0, m, &cVar_OtGhFBXU_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KkbpKawz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mlD6JQhQ, 0, m, &cVar_mlD6JQhQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ge9fNW25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_s7UcZAU1, 1, m, &cIf_s7UcZAU1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_duWuAGxz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_udjtFJzH, 0, m, &cVar_udjtFJzH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Zp0tHKm5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ngiFjMZw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5lRLW921_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8MeNqaCe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SaJqrxEZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EQ6tx7j8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SaJqrxEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Uqs9PG6N, 1, m, &cIf_Uqs9PG6N_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EQ6tx7j8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1KaVOf5b, 0, m, &cVar_1KaVOf5b_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ngiFjMZw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IahScxMj, 1, m, &cIf_IahScxMj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_5lRLW921_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_udjtFJzH, 0, m, &cVar_udjtFJzH_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_l5YlPANR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dR1uxmMW, 0, m, &cVar_dR1uxmMW_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_6LNuIp7k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HOgPLNOB, 0, m, &cVar_HOgPLNOB_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_P0rBhJPP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2V4smvIF, 0, m, &cVar_2V4smvIF_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_XuqzZIq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gEoBKNm3, 0, m, &cVar_gEoBKNm3_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_EyUFn9HR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_I0SwtZ2k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yQ5FemQF_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_8iZnyDbT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FVRyNwJZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TPaBRAGK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E2EpjCiG_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_iaBtc92z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NKLZegpH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nYOg2LHA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mfV3Mjqp_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_0PhYcJuQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s9ApuWQq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lMeGc6TP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1EOygAtY_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_VBRaPX97_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l3vCPlxs_sendMessage(_c, 0, m);
  cMsg_qM6wHyOj_sendMessage(_c, 0, m);
  cMsg_ZooNLd4Y_sendMessage(_c, 0, m);
  cMsg_jChOZhxt_sendMessage(_c, 0, m);
  cMsg_UShumYBb_sendMessage(_c, 0, m);
  cMsg_fb5fjYVz_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_sHJen0hU, 0, m, &cVar_sHJen0hU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gEoBKNm3, 0, m, &cVar_gEoBKNm3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RvuVwxs4, 0, m, &cVar_RvuVwxs4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qik2bFSf, 0, m, &cVar_qik2bFSf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cNnpjLqv, 0, m, &cVar_cNnpjLqv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PoIJfAbL, 0, m, &cVar_PoIJfAbL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zSd7KgEg, 0, m, &cVar_zSd7KgEg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Vs7HjouW, 0, m, &cVar_Vs7HjouW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_w89zrCSU, 0, m, &cVar_w89zrCSU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4BBwMvBi, 0, m, &cVar_4BBwMvBi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SN8ntG52, 0, m, &cVar_SN8ntG52_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JvN7CrtE, 0, m, &cVar_JvN7CrtE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fadgWOAN, 0, m, &cVar_fadgWOAN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LByYkg0G, 0, m, &cVar_LByYkg0G_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wvrbnpa8, 0, m, &cVar_wvrbnpa8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_upfMbw8d, 0, m, &cVar_upfMbw8d_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ag0p5hQn, 0, m, &cVar_Ag0p5hQn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_E5yKBeIZ, 0, m, &cVar_E5yKBeIZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_s39Iwr0U, 0, m, &cVar_s39Iwr0U_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2RamqhcC, 0, m, &cVar_2RamqhcC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BmO7BZOM, 0, m, &cVar_BmO7BZOM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TV64yr9j, 0, m, &cVar_TV64yr9j_sendMessage);
  cMsg_PRtjYlTE_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_OI6Ec8Ao, 0, m, &cVar_OI6Ec8Ao_sendMessage);
  cMsg_NoJnST5e_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_MsxTifPA, 0, m, &cVar_MsxTifPA_sendMessage);
  cMsg_rPmTdWsY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ntq0mLW8, 0, m, &cVar_ntq0mLW8_sendMessage);
  cMsg_j5LNE8kD_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_RJIwwFYB, 0, m, &cVar_RJIwwFYB_sendMessage);
  cMsg_CCssk4IR_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_QPRAVli1, 0, m, &cVar_QPRAVli1_sendMessage);
  cMsg_F3Cjl6W5_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_P5XMJ71r, 0, m, &cVar_P5XMJ71r_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7dIGjUJA, 0, m, &cVar_7dIGjUJA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Oi0aItS1, 0, m, &cVar_Oi0aItS1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tfZoSHmm, 0, m, &cVar_tfZoSHmm_sendMessage);
  cMsg_E21JjdkY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_9be1RhPi, 0, m, &cVar_9be1RhPi_sendMessage);
  cMsg_dcZvognO_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_KVhsrcX9, 0, m, &cVar_KVhsrcX9_sendMessage);
  cMsg_S0vYUkfs_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_vhgz510u, 0, m, &cVar_vhgz510u_sendMessage);
  cMsg_sDM3Nrk4_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_50erY1lu, 0, m, &cVar_50erY1lu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_C8dCOkNW, 0, m, &cVar_C8dCOkNW_sendMessage);
  cMsg_Z8s9xUCu_sendMessage(_c, 0, m);
  cMsg_I6vpCizT_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_KcVLL99y, 0, m, &cVar_KcVLL99y_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KOCYpNNc, 0, m, &cVar_KOCYpNNc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_twrwoVBr, 0, m, &cVar_twrwoVBr_sendMessage);
  cMsg_XnxXfaFP_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_NGf4sACI, 0, m, &cVar_NGf4sACI_sendMessage);
  cMsg_dlWvRLX5_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_JZUyP15e, 0, m, &cVar_JZUyP15e_sendMessage);
  cMsg_cczg3qA2_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_7HoPe3eF, 0, m, &cVar_7HoPe3eF_sendMessage);
  cMsg_1wLe47KV_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_oSLhhQCu, 0, m, &cVar_oSLhhQCu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NLdwqvYZ, 0, m, &cVar_NLdwqvYZ_sendMessage);
  cMsg_JeZdMDLI_sendMessage(_c, 0, m);
  cMsg_hGQpA73H_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_tf6Mdqsa, 0, m, &cVar_tf6Mdqsa_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UpkDqmkD, 0, m, &cVar_UpkDqmkD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5PP4lbpI, 0, m, &cVar_5PP4lbpI_sendMessage);
  cMsg_XmhRH36s_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_JpEMlwb1, 0, m, &cVar_JpEMlwb1_sendMessage);
  cMsg_ZpHUlfLI_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_6KlGhQZQ, 0, m, &cVar_6KlGhQZQ_sendMessage);
  cMsg_hJr2oX8A_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_FGIjolnh, 0, m, &cVar_FGIjolnh_sendMessage);
  cMsg_NWjPGLmw_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_JMqrIxpG, 0, m, &cVar_JMqrIxpG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OEqys86i, 0, m, &cVar_OEqys86i_sendMessage);
  cMsg_YdFA5qeN_sendMessage(_c, 0, m);
  cMsg_3gtSACcE_sendMessage(_c, 0, m);
  cMsg_81uVh4tr_sendMessage(_c, 0, m);
  cMsg_8tveOxt4_sendMessage(_c, 0, m);
  cMsg_aLYqleZw_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_FDcNsqkJ, 0, m, &cVar_FDcNsqkJ_sendMessage);
  cMsg_SZrlXFXd_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_501pHXEM, 0, m, &cTabhead_501pHXEM_sendMessage);
  cMsg_QwrrTqbt_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_1t0kq9gj, 0, m, &cVar_1t0kq9gj_sendMessage);
  cMsg_ZSCsaUV6_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_qNTM3jpW, 0, m, &cTabhead_qNTM3jpW_sendMessage);
  cMsg_lhEA0vVw_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_MQ2AKT9H, 0, m, &cVar_MQ2AKT9H_sendMessage);
  cMsg_ABB6w7TE_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_0X7J4I9b, 0, m, &cTabhead_0X7J4I9b_sendMessage);
  cMsg_osLcp4O6_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_eClkqDOl, 0, m, &cVar_eClkqDOl_sendMessage);
  cMsg_G8Zpgsi9_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_mT1FtaSr, 0, m, &cTabhead_mT1FtaSr_sendMessage);
  cMsg_Z73hfvJc_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_HqC4WwzQ, 0, m, &cVar_HqC4WwzQ_sendMessage);
  cMsg_MaJ0gCgV_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_ij6xZJJZ, 0, m, &cTabhead_ij6xZJJZ_sendMessage);
  cMsg_ZAUopW4Q_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_oLo6Abwe, 0, m, &cVar_oLo6Abwe_sendMessage);
  cMsg_o5hDE6vn_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_MMf7dAwu, 0, m, &cTabhead_MMf7dAwu_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_36I8aJvo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I14B8NfX, HV_BINOP_MULTIPLY, 0, m, &cBinop_I14B8NfX_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_AZIaGbdA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_qiMFx7OX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_e1mPc1dk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_rAylZzAA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_9GxaB2GQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Q0XkogfL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_lmIOuSqY_sendMessage);
  cMsg_9f2vNcpZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_SpQMju7o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k7cM7Nw0, HV_BINOP_MULTIPLY, 0, m, &cBinop_k7cM7Nw0_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_K6m7ndzZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_OfgnMt4D_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Splwcva7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hQeeyKUi, HV_BINOP_MULTIPLY, 1, m, &cBinop_hQeeyKUi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_nTGVsBLl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9SbzRVkH_sendMessage);
  cMsg_M0QwdOe8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_O8uxkEN1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J5Ja3V6Q, HV_BINOP_MULTIPLY, 0, m, &cBinop_J5Ja3V6Q_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_j68hgm05_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9jvKafx7_sendMessage(_c, 0, m);
  cMsg_6Lubx88D_sendMessage(_c, 0, m);
  cMsg_UwaNrMqg_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_pBaEofci_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_S7wx4BBf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_bh4UufRU_sendMessage);
  cMsg_sq5ssufF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_AiONJNy3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cNnpjLqv, 0, m, &cVar_cNnpjLqv_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_i7GmvdGM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BpY8d0GA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dursrFMV_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Bfe16qRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZOKe5o2B_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2fVIiECc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C7yPvR6N_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_U6QmyAOU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ggJqxS9r_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lEY0KVXg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jcAoC2B6_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_qU52r1oc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hNBpG5Ou_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4hVpx9M8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Varg3UKY_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_tD13uiYd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rT9T5ggx, HV_BINOP_MULTIPLY, 0, m, &cBinop_rT9T5ggx_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_QAz1QfFU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_8woAAECK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_RtzEMrwe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_27yKdsU1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_La97wcfh_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_3DbQjhK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ldnGpjLm_sendMessage);
  cMsg_vBYRR3Zu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_y0YtL7mR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rH3uiKi9, HV_BINOP_MULTIPLY, 0, m, &cBinop_rH3uiKi9_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_fgiAS9DF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_UQKIw3Q6_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_akKFT5zN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vpGVGSxu, HV_BINOP_MULTIPLY, 1, m, &cBinop_vpGVGSxu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_gIse6nGo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_0qyon56E_sendMessage);
  cMsg_R9sK9mtr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_ftUe7eu9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7VQ7E3hh, HV_BINOP_MULTIPLY, 0, m, &cBinop_7VQ7E3hh_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_abH5EQJO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gMVjlnhU_sendMessage(_c, 0, m);
  cMsg_gn63aBNR_sendMessage(_c, 0, m);
  cMsg_HhirfhE1_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_zJWDCsrN_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_mUvvbtAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_yFsE1NCA_sendMessage);
  cMsg_0ibGG6L4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_mNPW0xqk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_P0SMmeIA, 0, m, &cVar_P0SMmeIA_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_qIVQVJwp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_X5ZKbpKM_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_MfldQihN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_eac7whUf_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_vpJTibK7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_oSl2oxER_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_xJWoTulK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_iIM5BbuK_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_bUnPoUf9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_U2hmZwQP_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_deqhjGaV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_KZnkMZRu_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Vc64Ccxj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_llh3XFtO_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_gHhy1M9Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_W0ESkSaZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_MsUZcA8e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_MgAOYnLo_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_z6VVibfw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QiKoG0dW, HV_BINOP_MULTIPLY, 1, m, &cBinop_QiKoG0dW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8BB334gL_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xEPyIa8F, HV_BINOP_MULTIPLY, 1, m, &cBinop_xEPyIa8F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sWR5VXXV_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_rddF7YSt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Qyzx8RGU, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_eyK59vya, m);
}

void Heavy_WSTD_DL3Y::cReceive_EBjuxtS3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_UewITmOC_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_8NPlFAF1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_vnxZHux1_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_YtBpbUiv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GARuUu9p, HV_BINOP_MULTIPLY, 1, m, &cBinop_GARuUu9p_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4bCBqSx6_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yYzzHPYh, HV_BINOP_MULTIPLY, 1, m, &cBinop_yYzzHPYh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Hesjxc3E_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_H8N4ZzCi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_OgS8SSWo, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_8waQ0F4l, m);
}

void Heavy_WSTD_DL3Y::cReceive_QsXtVNzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_v4tgZFaa_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_fU0nJisv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_FqDTX5Aq_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_I7S7dz8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_apxm0LdI, HV_BINOP_MULTIPLY, 1, m, &cBinop_apxm0LdI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n1BRn1Pf_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_SEki2U0h, HV_BINOP_MULTIPLY, 1, m, &cBinop_SEki2U0h_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vUDicrE4_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_GpVZMMNT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_DRd2msG8, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Ldjf8K9x, m);
}

void Heavy_WSTD_DL3Y::cReceive_hTplozxz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_zaY5PYBS_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_OQgR9ls7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_daEjz6zh_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_wFyC7xJ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9aJY6LP6, 0, m, &cVar_9aJY6LP6_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_TR3SjFZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nRZyyCus, 0, m, &cVar_nRZyyCus_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_d78OjRp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_d6DUnOim, 0, m, &cVar_d6DUnOim_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_yC7TTC0X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OtGhFBXU, 0, m, &cVar_OtGhFBXU_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_22Xwxn5F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1KaVOf5b, 0, m, &cVar_1KaVOf5b_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_LdwJz6Pn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FkEyWuef, 0, m, &cVar_FkEyWuef_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_GEt2yPdK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BHAV7Ycj, 0, m, &cVar_BHAV7Ycj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JaoQnoqx, 0, m, &cVar_JaoQnoqx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1kQOeo2Y, 0, m, &cVar_1kQOeo2Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_sdtm0r2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_1NpiGfE9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_5OjprXhm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_uHNDRm5H_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_YxOZKWCz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0Lgqp6Cb_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DL3Y::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_HfB8f7Kh, VOf(Bf0));
    __hv_line_f(&sLine_alTVnMXF, VOf(Bf1));
    __hv_line_f(&sLine_KwGtZbyF, VOf(Bf2));
    __hv_line_f(&sLine_Pd4be4B6, VOf(Bf3));
    __hv_line_f(&sLine_KkIkFAF3, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_YMA7I0lb, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_KZAOeiZd, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_qoUDselp, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_vL3RoZiy, VOf(Bf1));
    __hv_line_f(&sLine_scCwlgNL, VOf(Bf0));
    __hv_line_f(&sLine_4heJ8ozW, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_B6fh4qWa, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_rtYFa6uk, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_gjgZU9yb, VOf(Bf5));
    __hv_line_f(&sLine_p3SPLn1E, VOf(Bf1));
    __hv_line_f(&sLine_qzWRJBPU, VOf(Bf2));
    __hv_line_f(&sLine_Uxy0D7ls, VOf(Bf4));
    __hv_line_f(&sLine_et3qMfIx, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_KXwt20U1, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_4KBeqg7p, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_buIO0R4L, VOf(Bf6));
    __hv_line_f(&sLine_BmUcqCOC, VOf(Bf2));
    __hv_line_f(&sLine_PBY1jd7q, VOf(Bf1));
    __hv_line_f(&sLine_vuzcBGAp, VOf(Bf5));
    __hv_line_f(&sLine_UwBlNfmI, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_bNOdBFrR, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_qVE7YLk9, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_eo17yxQ0, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_jnZrF0HV, VOf(Bf2));
    __hv_line_f(&sLine_urFMGpSK, VOf(Bf6));
    __hv_line_f(&sLine_cayeb2i8, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_xlScPdSJ, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_YwcIDpxR, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_WGibibhE, VOf(Bf8));
    __hv_line_f(&sLine_G6gOMWzu, VOf(Bf2));
    __hv_line_f(&sLine_zQ2Y2qt8, VOf(Bf1));
    __hv_line_f(&sLine_vPZYf5m3, VOf(Bf7));
    __hv_line_f(&sLine_XTkMygb3, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_2ysZNWU5, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_mqgeQyyS, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_mAsrNk8o, VOf(Bf9));
    __hv_tabread_f(&sTabread_F22A441M, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_Z3jkDBZ1, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_IxAyg3cQ, VOf(Bf9));
    __hv_tabread_f(&sTabread_qvGLJlfv, VOf(Bf8));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_pKiTGsMO, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_6WDE2U7D, VOf(Bf9));
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_8GC5h7Mw, VOf(Bf3));
    __hv_rpole_f(&sRPole_Q2Yhb3Xw, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_BsKastg3, VIf(Bf3), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_BfTPhOAN, VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_FZBcJac7, VIf(Bf3));
    __hv_varread_f(&sVarf_S3l9t3k4, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_SUO9eorV, VOf(Bf5));
    __hv_rpole_f(&sRPole_2715Jlpd, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_9RR17UoQ, VIf(Bf5), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_3jG7cdfA, VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_a5QJ4eun, VIf(Bf5));
    __hv_varread_f(&sVarf_Qyzx8RGU, VOf(Bf5));
    __hv_mul_f(VIf(Bf1), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_9J54lYWS, VOf(Bf1));
    __hv_varread_f(&sVarf_eyK59vya, VOf(Bf3));
    __hv_mul_f(VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_egE49uz6, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_QlwrnJpB, VOf(Bf1));
    __hv_varread_f(&sVarf_SeSclvrj, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_ybMNApE6, VOf(Bf1));
    __hv_rpole_f(&sRPole_mjbbPxgw, VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_pPlNAAca, VIf(Bf8), &sEnv_pPlNAAca_sendMessage);
    __hv_varread_f(&sVarf_4sTvt7Sf, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_yYKnDHh0, VOf(Bf1));
    __hv_rpole_f(&sRPole_0eLfua49, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_6WDE2U7D, VIf(Bf1));
    __hv_line_f(&sLine_1kP4rgcD, VOf(Bf1));
    __hv_line_f(&sLine_IEHxJXbg, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_93erCWOz, VOf(Bf1));
    __hv_varread_f(&sVarf_JqnFYYDH, VOf(Bf3));
    __hv_mul_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_hEgBI23K, VOf(Bf1));
    __hv_rpole_f(&sRPole_qBYtgXPV, VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_yvXQmYyh, VIf(Bf8), &sEnv_yvXQmYyh_sendMessage);
    __hv_varread_f(&sVarf_MGowtGG9, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_HCMyTsDp, VOf(Bf1));
    __hv_rpole_f(&sRPole_tnQ8pSDX, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_S3l9t3k4, VIf(Bf1));
    __hv_varwrite_f(&sVarf_OUeGviFG, VIf(Bf2));
    __hv_varread_f(&sVarf_Ttip5cdU, VOf(Bf2));
    __hv_varread_f(&sVarf_hEnjjWKg, VOf(Bf1));
    __hv_line_f(&sLine_wEoA3xCZ, VOf(Bf8));
    __hv_tabread_f(&sTabread_AyNIbarD, VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_EVon1jSf, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf2), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_OMQsBF0A, VOf(Bf8));
    __hv_tabread_f(&sTabread_hauLLylu, VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_tCIdo3OO, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf1), VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_W7iTzzJm, VOf(Bf8));
    __hv_add_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_bk20T1U6, VOf(Bf2));
    __hv_rpole_f(&sRPole_6i7Ye4m4, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_DdetReD7, VIf(Bf2), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_sub_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_U8n5Zwo5, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_tabwrite_f(&sTabwrite_k6EX2Ec1, VIf(Bf2));
    __hv_varread_f(&sVarf_y9PLbjFQ, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_5xDC1acT, VOf(Bf1));
    __hv_rpole_f(&sRPole_T0WnH4Df, VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_MyrUwGdw, VIf(Bf1), VOf(Bf8));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_AsFhoWNn, VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_7AZkZ8k8, VIf(Bf1));
    __hv_varread_f(&sVarf_OgS8SSWo, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_1eD5HXG7, VOf(Bf3));
    __hv_varread_f(&sVarf_8waQ0F4l, VOf(Bf2));
    __hv_mul_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_nAl6Eubo, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf1), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_AsLYJncj, VOf(Bf3));
    __hv_varread_f(&sVarf_uYPmLM6c, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_aI3jOREu, VOf(Bf3));
    __hv_rpole_f(&sRPole_zRzRVyHy, VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_npDA7nk6, VIf(Bf9), &sEnv_npDA7nk6_sendMessage);
    __hv_varread_f(&sVarf_Yb5oFF0V, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_VrsB78nb, VOf(Bf3));
    __hv_rpole_f(&sRPole_CpuLz2kO, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_W7iTzzJm, VIf(Bf3));
    __hv_line_f(&sLine_LGOOWNep, VOf(Bf3));
    __hv_line_f(&sLine_vX2wY3s1, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_L0m9w3fL, VOf(Bf3));
    __hv_varread_f(&sVarf_UFSFwlvR, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_LDno1WxL, VOf(Bf3));
    __hv_rpole_f(&sRPole_qPLKnl10, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_AFkwDwwx, VIf(Bf9), &sEnv_AFkwDwwx_sendMessage);
    __hv_varread_f(&sVarf_SGCurf8n, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_iLZtWhFM, VOf(Bf3));
    __hv_rpole_f(&sRPole_XAtU9b5P, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_y9PLbjFQ, VIf(Bf3));
    __hv_varwrite_f(&sVarf_a29lGdHP, VIf(Bf5));
    __hv_varread_f(&sVarf_AOH058z7, VOf(Bf5));
    __hv_varread_f(&sVarf_sYwVWEWn, VOf(Bf3));
    __hv_line_f(&sLine_PdXXWjW3, VOf(Bf9));
    __hv_tabread_f(&sTabread_OhtVlxcf, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_QpnaNcY1, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_WGF5eXzV, VOf(Bf9));
    __hv_tabread_f(&sTabread_X2EEAVfE, VOf(Bf8));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_Sz1FCUmg, VOf(Bf12));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_h9GEjUT0, VOf(Bf9));
    __hv_add_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_cCFfodNy, VOf(Bf5));
    __hv_rpole_f(&sRPole_uMXh1QAP, VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_lNmLPvoo, VIf(Bf5), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_RnPQOUXa, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_gGztJXJA, VIf(Bf5));
    __hv_varread_f(&sVarf_5qgFHSVj, VOf(Bf5));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_OQUjnLcN, VOf(Bf3));
    __hv_rpole_f(&sRPole_MxBeHuT9, VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_PgIayqgi, VIf(Bf3), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_G73wGL4l, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_YiOIMMZD, VIf(Bf3));
    __hv_varread_f(&sVarf_DRd2msG8, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_RiiDhfRN, VOf(Bf2));
    __hv_varread_f(&sVarf_Ldjf8K9x, VOf(Bf5));
    __hv_mul_f(VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_W0LaHzsa, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_4B923pwn, VOf(Bf2));
    __hv_varread_f(&sVarf_BApyv1Gq, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_EmUKfeuo, VOf(Bf2));
    __hv_rpole_f(&sRPole_Y8CtWcFE, VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_OYV90pPc, VIf(Bf8), &sEnv_OYV90pPc_sendMessage);
    __hv_varread_f(&sVarf_rDlQJ2It, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_I1VDkNm9, VOf(Bf2));
    __hv_rpole_f(&sRPole_ob2RWZXn, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_h9GEjUT0, VIf(Bf2));
    __hv_line_f(&sLine_8J98VVQg, VOf(Bf2));
    __hv_line_f(&sLine_B8XC1E0x, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_RJWhLfGq, VOf(Bf2));
    __hv_varread_f(&sVarf_yYc0wpvi, VOf(Bf5));
    __hv_mul_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_DaCUl07F, VOf(Bf2));
    __hv_rpole_f(&sRPole_zrv8PUwB, VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_teB4zooV, VIf(Bf8), &sEnv_teB4zooV_sendMessage);
    __hv_varread_f(&sVarf_21BZj11C, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_ABBx7l3m, VOf(Bf2));
    __hv_rpole_f(&sRPole_IqtMGWcU, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_5qgFHSVj, VIf(Bf2));
    __hv_varwrite_f(&sVarf_oTznAKkf, VIf(Bf1));
    __hv_varwrite_f(&sVarf_hfkmtLuX, VIf(Bf10));
    __hv_varwrite_f(&sVarf_8tUDUPrt, VIf(Bf11));
    __hv_varwrite_f(&sVarf_DsGmyjFe, VIf(Bf12));
    __hv_varwrite_f(&sVarf_Ttip5cdU, VIf(Bf0));
    __hv_varwrite_f(&sVarf_hEnjjWKg, VIf(Bf6));
    __hv_varwrite_f(&sVarf_AOH058z7, VIf(Bf4));
    __hv_varwrite_f(&sVarf_sYwVWEWn, VIf(Bf7));
    __hv_varread_f(&sVarf_hfkmtLuX, VOf(Bf7));
    __hv_varread_f(&sVarf_8tUDUPrt, VOf(Bf4));
    __hv_varread_f(&sVarf_DsGmyjFe, VOf(Bf6));
    __hv_add_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_OUeGviFG, VOf(Bf6));
    __hv_varread_f(&sVarf_a29lGdHP, VOf(Bf7));
    __hv_varread_f(&sVarf_oTznAKkf, VOf(Bf4));
    __hv_add_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf4), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DL3Y::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DL3Y::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
